@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: args.h 986 2006-02-10 10:57:10Z cstim $
+    cvs         : $Id: args.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Sat Apr 24 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -75,9 +75,8 @@ typedef enum {
  * Developer's note: Please note that any change within this struct will
  * make it necessary to increment the SO_VERSION of the library !
  */
-GWENHYWFAR_API
 struct GWEN_ARGS {
-  GWEN_TYPE_UINT32 flags;
+  uint32_t flags;
   GWEN_ARGS_TYPE type;
   const char *name;
   unsigned int minNum;
@@ -98,7 +97,7 @@ struct GWEN_ARGS {
 GWENHYWFAR_API
 int GWEN_Args_Check(int argc, char **argv,
 		    int startAt,
-		    GWEN_TYPE_UINT32 mode,
+		    uint32_t mode,
 		    const GWEN_ARGS *args,
 		    GWEN_DB_NODE *db);
 
