@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: buffer.h 1043 2006-05-04 20:54:17Z martin $
+    cvs         : $Id: buffer.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Fri Sep 12 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -45,6 +45,7 @@ typedef struct GWEN_BUFFER GWEN_BUFFER;
 
 #include <gwenhywfar/types.h>
 #include <gwenhywfar/bufferedio.h>
+#include <gwenhywfar/iolayer.h>
 
 
 #include <stdio.h>
@@ -64,11 +65,12 @@ extern "C" {
  */
 /*@{*/
 
-#define GWEN_BUFFER_MAX_BOOKMARKS 4
+#define GWEN_BUFFER_MAX_BOOKMARKS 32
 
 #define GWEN_BUFFER_MODE_DYNAMIC          0x0001
 #define GWEN_BUFFER_MODE_ABORT_ON_MEMFULL 0x0002
 #define GWEN_BUFFER_MODE_USE_BIO          0x0004
+#define GWEN_BUFFER_MODE_USE_IO           0x0008
 
 #define GWEN_BUFFER_MODE_DEFAULT \
   (\
@@ -102,8 +104,8 @@ extern "C" {
  */
 GWENHYWFAR_API
 GWEN_BUFFER *GWEN_Buffer_new(char *buffer,
-                             GWEN_TYPE_UINT32 size,
-                             GWEN_TYPE_UINT32 used,
+                             uint32_t size,
+                             uint32_t used,
                              int take_ownership);
 
 /** Frees the given buffer. 
@@ -121,47 +123,58 @@ GWENHYWFAR_API
 GWEN_BUFFER *GWEN_Buffer_dup(GWEN_BUFFER *bf);
 
 
+/** This function relinquishes ownership of the internal buffer
+ * if possible. It returns an error if this object does not own the
+ * buffer (it can't give you what it doesn't possess) or if the
+ * internal pointer to the memory allocated does not match the internal
+ * pointer to the current start of the buffer (this can be the case
+ * when @ref GWEN_Buffer_ReserveBytes() of @ref GWEN_Buffer_Crop()
+ * have been called).
+ */
+GWENHYWFAR_API
+int GWEN_Buffer_Relinquish(GWEN_BUFFER *bf);
+
 /**
  * Returns the current mode of the buffer
  * (such as  @ref GWEN_BUFFER_MODE_DYNAMIC).
  */
 GWENHYWFAR_API
-GWEN_TYPE_UINT32 GWEN_Buffer_GetMode(GWEN_BUFFER *bf);
+uint32_t GWEN_Buffer_GetMode(GWEN_BUFFER *bf);
 
 /**
  * Changes the current mode of the buffer
  * (such as  @ref GWEN_BUFFER_MODE_DYNAMIC).
  */
 GWENHYWFAR_API
-void GWEN_Buffer_SetMode(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 mode);
+void GWEN_Buffer_SetMode(GWEN_BUFFER *bf, uint32_t mode);
 
 /**
  * Adds the give mode to the current mode of the buffer
  * (such as  @ref GWEN_BUFFER_MODE_DYNAMIC).
  */
 GWENHYWFAR_API
-void GWEN_Buffer_AddMode(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 mode);
+void GWEN_Buffer_AddMode(GWEN_BUFFER *bf, uint32_t mode);
 
 /**
  * Removes the give mode from the current mode of the buffer
  * (such as  @ref GWEN_BUFFER_MODE_DYNAMIC).
  */
 GWENHYWFAR_API
-void GWEN_Buffer_SubMode(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 mode);
+void GWEN_Buffer_SubMode(GWEN_BUFFER *bf, uint32_t mode);
 
 /**
  * Returns the hard limit. This is the maximum size of a GWEN_BUFFER in
  * dynamic mode.
  */
 GWENHYWFAR_API
-GWEN_TYPE_UINT32 GWEN_Buffer_GetHardLimit(GWEN_BUFFER *bf);
+uint32_t GWEN_Buffer_GetHardLimit(GWEN_BUFFER *bf);
 
 /**
  * Changes the hard limit. This is the maximum size of a GWEN_BUFFER in
  * dynamic mode.
  */
 GWENHYWFAR_API
-void GWEN_Buffer_SetHardLimit(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 l);
+void GWEN_Buffer_SetHardLimit(GWEN_BUFFER *bf, uint32_t l);
 
 
 /**
@@ -170,7 +183,7 @@ void GWEN_Buffer_SetHardLimit(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 l);
  * The allocated data in total for this buffer will be aligned to this value.
  */
 GWENHYWFAR_API
-GWEN_TYPE_UINT32 GWEN_Buffer_GetStep(GWEN_BUFFER *bf);
+uint32_t GWEN_Buffer_GetStep(GWEN_BUFFER *bf);
 
 /**
  * In dynamic mode, whenever there is new data to allocate then this value
@@ -180,7 +193,7 @@ GWEN_TYPE_UINT32 GWEN_Buffer_GetStep(GWEN_BUFFER *bf);
  * only ONE bit must be set !)
  */
 GWENHYWFAR_API
-void GWEN_Buffer_SetStep(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 step);
+void GWEN_Buffer_SetStep(GWEN_BUFFER *bf, uint32_t step);
 
 
 /**
@@ -192,7 +205,7 @@ void GWEN_Buffer_SetStep(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 step);
  * inserting bytes at the beginning of the buffer.
  */
 GWENHYWFAR_API
-int GWEN_Buffer_ReserveBytes(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 res);
+int GWEN_Buffer_ReserveBytes(GWEN_BUFFER *bf, uint32_t res);
 
 
 /**
@@ -207,7 +220,7 @@ char *GWEN_Buffer_GetStart(GWEN_BUFFER *bf);
  * Returns the size of the buffer (i.e. the number of bytes allocated).
  */
 GWENHYWFAR_API
-GWEN_TYPE_UINT32 GWEN_Buffer_GetSize(GWEN_BUFFER *bf);
+uint32_t GWEN_Buffer_GetSize(GWEN_BUFFER *bf);
 
 
 /**
@@ -215,25 +228,25 @@ GWEN_TYPE_UINT32 GWEN_Buffer_GetSize(GWEN_BUFFER *bf);
  * by the various read and write functions.
  */
 GWENHYWFAR_API
-GWEN_TYPE_UINT32 GWEN_Buffer_GetPos(GWEN_BUFFER *bf);
+uint32_t GWEN_Buffer_GetPos(GWEN_BUFFER *bf);
 
 /**
  * @return 0 if ok, !=0 on error
  */
 GWENHYWFAR_API
-int GWEN_Buffer_SetPos(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 i);
+int GWEN_Buffer_SetPos(GWEN_BUFFER *bf, uint32_t i);
 
 /**
  */
 GWENHYWFAR_API
-GWEN_TYPE_UINT32 GWEN_Buffer_GetUsedBytes(GWEN_BUFFER *bf);
+uint32_t GWEN_Buffer_GetUsedBytes(GWEN_BUFFER *bf);
 
 
 /**
  * Returns the given bookmark
  */
 GWENHYWFAR_API
-GWEN_TYPE_UINT32 GWEN_Buffer_GetBookmark(GWEN_BUFFER *bf, unsigned int idx);
+uint32_t GWEN_Buffer_GetBookmark(GWEN_BUFFER *bf, unsigned int idx);
 
 
 /**
@@ -242,14 +255,14 @@ GWEN_TYPE_UINT32 GWEN_Buffer_GetBookmark(GWEN_BUFFER *bf, unsigned int idx);
  */
 GWENHYWFAR_API
 void GWEN_Buffer_SetBookmark(GWEN_BUFFER *bf, unsigned int idx,
-                             GWEN_TYPE_UINT32 v);
+                             uint32_t v);
 
 
 /**
  * @return 0 if ok, !=0 on error
  */
 GWENHYWFAR_API
-int GWEN_Buffer_SetUsedBytes(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 i);
+int GWEN_Buffer_SetUsedBytes(GWEN_BUFFER *bf, uint32_t i);
 
 /**
  * Copies the contents of the given buffer to this GWEN_BUFFER, if there is
@@ -260,17 +273,17 @@ int GWEN_Buffer_SetUsedBytes(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 i);
 GWENHYWFAR_API
 int GWEN_Buffer_AppendBytes(GWEN_BUFFER *bf,
                             const char *buffer,
-                            GWEN_TYPE_UINT32 size);
+                            uint32_t size);
 
 GWENHYWFAR_API
 int GWEN_Buffer_FillWithBytes(GWEN_BUFFER *bf,
                               unsigned char c,
-                              GWEN_TYPE_UINT32 size);
+                              uint32_t size);
 
 GWENHYWFAR_API
 int GWEN_Buffer_FillLeftWithBytes(GWEN_BUFFER *bf,
                                   unsigned char c,
-                                  GWEN_TYPE_UINT32 size);
+                                  uint32_t size);
 
 
 /**
@@ -304,7 +317,7 @@ int GWEN_Buffer_AppendByte(GWEN_BUFFER *bf, char c);
 GWENHYWFAR_API
 int GWEN_Buffer_InsertBytes(GWEN_BUFFER *bf,
                             const char *buffer,
-                            GWEN_TYPE_UINT32 size);
+                            uint32_t size);
 
 /**
  * This function makes room for the given number of bytes at the current
@@ -314,10 +327,40 @@ int GWEN_Buffer_InsertBytes(GWEN_BUFFER *bf,
  * at that position there is the begin of the newly inserted room.
  * All pointers obtained from this module (e.g. via
  * @ref GWEN_Buffer_GetStart) become invalid !
+ * This function updates the bookmarks accordingly.
  */
 GWENHYWFAR_API
 int GWEN_Buffer_InsertRoom(GWEN_BUFFER *bf,
-                           GWEN_TYPE_UINT32 size);
+                           uint32_t size);
+
+/**
+ * This function removes the given number of bytes at the current
+ * buffer position. It moves any existing bytes behind the area to be removed
+ * to the current position.
+ * The position pointer will not be altered, but after calling this function
+ * at that position there is the begin of the data behind the removed area.
+ * All pointers obtained from this module (e.g. via
+ * @ref GWEN_Buffer_GetStart) become invalid !
+ * This function updates the bookmarks accordingly.
+ */
+GWENHYWFAR_API
+int GWEN_Buffer_RemoveRoom(GWEN_BUFFER *bf, uint32_t size);
+
+/**
+ * This function remplaces the given number of bytes at the current
+ * buffer position with some new bytes. If the number of bytes to be replaced
+ * does not equal the number of replacement bytes then the buffer is resized
+ * accordingly (e.g. shrunk or extended).
+ * The position pointer will not be altered.
+ * All pointers obtained from this module (e.g. via
+ * @ref GWEN_Buffer_GetStart) become invalid !
+ * This function updates the bookmarks accordingly.
+ */
+GWENHYWFAR_API
+int GWEN_Buffer_ReplaceBytes(GWEN_BUFFER *bf,
+			     uint32_t rsize,
+			     const char *buffer,
+			     uint32_t size);
 
 
 /**
@@ -327,6 +370,7 @@ int GWEN_Buffer_InsertRoom(GWEN_BUFFER *bf,
  * at that position there is the begin of the newly inserted string.
  * All pointers obtained from this module (e.g. via
  * @ref GWEN_Buffer_GetStart) become invalid !
+ * This function updates the bookmarks accordingly.
  */
 GWENHYWFAR_API
 int GWEN_Buffer_InsertString(GWEN_BUFFER *bf,
@@ -342,6 +386,7 @@ int GWEN_Buffer_InsertString(GWEN_BUFFER *bf,
  * at that position there is the begin of the newly inserted byte.
  * All pointers obtained from this module (e.g. via
  * @ref GWEN_Buffer_GetStart) become invalid !
+ * This function updates the bookmarks accordingly.
  */
 GWENHYWFAR_API
 int GWEN_Buffer_InsertByte(GWEN_BUFFER *bf, char c);
@@ -363,7 +408,7 @@ int GWEN_Buffer_ReadByte(GWEN_BUFFER *bf);
 GWENHYWFAR_API
 int GWEN_Buffer_ReadBytes(GWEN_BUFFER *bf,
                           char *buffer,
-                          GWEN_TYPE_UINT32 *size);
+                          uint32_t *size);
 
 
 /**
@@ -378,12 +423,34 @@ int GWEN_Buffer_PeekByte(GWEN_BUFFER *bf);
 
 /** Move the position pointer forward by the given number @c i. */
 GWENHYWFAR_API
-int GWEN_Buffer_IncrementPos(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 i);
+int GWEN_Buffer_IncrementPos(GWEN_BUFFER *bf, uint32_t i);
 
 /** Move the position pointer backward by the given number @c i. */
 GWENHYWFAR_API
-int GWEN_Buffer_DecrementPos(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 i);
+int GWEN_Buffer_DecrementPos(GWEN_BUFFER *bf, uint32_t i);
 
+/**
+ * The functions @ref GWEN_Buffer_IncrementPos and @ref GWEN_Buffer_DecrementPos
+ * only modify the internal position pointer.
+ * This function here adjusts the number of used bytes to just before the internal
+ * position pointer. This is often used to avoid copying, like in the following
+ * example:
+ * @code
+ *
+ * char *p;
+ * int i;
+ *
+ * for (i=0; i<100; i++) {
+ *   GWEN_Buffer_AllocRoom(buffer, 512);
+ *   p=GWEN_Buffer_GetPosPtr(buffer);
+ *   READ_512_BYTES_TO_P;
+ *   GWEN_Buffer_IncrementPos(buffer, 512);
+ *   GWEN_Buffer_AdjustUsedBytes(buffer);
+ * }
+ *
+ * @endcode
+ *
+ */
 GWENHYWFAR_API
 int GWEN_Buffer_AdjustUsedBytes(GWEN_BUFFER *bf);
 
@@ -411,14 +478,14 @@ int GWEN_Buffer_AppendBuffer(GWEN_BUFFER *bf,
  * at once (i.e. without reallocation).
  */
 GWENHYWFAR_API
-GWEN_TYPE_UINT32 GWEN_Buffer_GetMaxUnsegmentedWrite(GWEN_BUFFER *bf);
+uint32_t GWEN_Buffer_GetMaxUnsegmentedWrite(GWEN_BUFFER *bf);
 
 
 /**
  * Returns the number of bytes from pos to the end of the used area.
  */
 GWENHYWFAR_API
-GWEN_TYPE_UINT32 GWEN_Buffer_GetBytesLeft(GWEN_BUFFER *bf);
+uint32_t GWEN_Buffer_GetBytesLeft(GWEN_BUFFER *bf);
 
 
 /**
@@ -445,14 +512,14 @@ void GWEN_Buffer_Rewind(GWEN_BUFFER *bf);
  * Make sure that the buffer has enough room for the given bytes.
  */
 GWENHYWFAR_API
-int GWEN_Buffer_AllocRoom(GWEN_BUFFER *bf, GWEN_TYPE_UINT32 size);
+int GWEN_Buffer_AllocRoom(GWEN_BUFFER *bf, uint32_t size);
 
 
 /* crops the buffer to the specified bytes */
 GWENHYWFAR_API
 int GWEN_Buffer_Crop(GWEN_BUFFER *bf,
-                     GWEN_TYPE_UINT32 pos,
-                     GWEN_TYPE_UINT32 l);
+                     uint32_t pos,
+                     uint32_t l);
 
 
 /**
@@ -467,6 +534,19 @@ void GWEN_Buffer_SetSourceBIO(GWEN_BUFFER *bf,
 			      GWEN_BUFFEREDIO *bio,
 			      int take);
 
+/**
+ * Sets the io layer to be used as a source.
+ * This io layer is used when a byte is to be returned while the buffer is
+ * empty (or the end of the buffer is reached). In such a case the missing
+ * bytes are read from this io layer if the mode contains
+ * @ref GWEN_BUFFER_MODE_USE_IO.
+ */
+GWENHYWFAR_API
+void GWEN_Buffer_SetSourceIoLayer(GWEN_BUFFER *bf,
+				  GWEN_IO_LAYER *io,
+				  int take);
+
+
 /** Print the current content of buffer @c bf into the file @c f. */
 GWENHYWFAR_API
 void GWEN_Buffer_Dump(GWEN_BUFFER *bf, FILE *f, unsigned int insert);
