@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: error_l.h 349 2004-05-06 11:02:04Z aquamaniac $
+    cvs         : $Id: error_l.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Tue Oct 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -33,12 +33,12 @@
 /**
  * Initializes this module.
  */
-GWEN_ERRORCODE GWEN_Error_ModuleInit();
+int GWEN_Error_ModuleInit();
 
 /**
  * Deinitializes this module.
  */
-GWEN_ERRORCODE GWEN_Error_ModuleFini();
+int GWEN_Error_ModuleFini();
 
 #endif /* MOD_ERROR_L_H */
 
