@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: i18n.h 663 2005-01-11 21:24:03Z aquamaniac $
+    cvs         : $Id: i18n.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Fri Sep 12 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -36,12 +36,6 @@
 #include <gwenhywfar/stringlist.h>
 
 
-#ifdef ENABLE_NLS
-# include <libintl.h>
-# include <locale.h>
-#endif
-
-
 
 #ifdef __cplusplus
 extern "C" {
@@ -56,6 +50,15 @@ GWEN_STRINGLIST *GWEN_I18N_GetCurrentLocaleList();
 GWENHYWFAR_API
 const char *GWEN_I18N_GetCurrentLocale();
 
+GWENHYWFAR_API
+const char *GWEN_I18N_Translate(const char *textdomain, const char *text);
+
+GWENHYWFAR_API
+int GWEN_I18N_BindTextDomain_Dir(const char *textdomain, const char *folder);
+
+GWENHYWFAR_API
+int GWEN_I18N_BindTextDomain_Codeset(const char *textdomain, const char *cs);
+
 #ifdef __cplusplus
 }
 #endif
