@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: i18n_l.h 617 2004-12-05 00:57:11Z aquamaniac $
+    cvs         : $Id: i18n_l.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Fri Sep 12 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -34,20 +34,17 @@
 #ifdef ENABLE_NLS
 # include <libintl.h>
 # include <locale.h>
-# define I18N(m) dgettext("gwenhywfar", m)
-# define I18S(m) m
-#else
-# define I18N(m) m
-# define I18S(m) m
 #endif
 
 #include <gwenhywfar/i18n.h>
 
 
-GWEN_ERRORCODE GWEN_I18N_ModuleInit();
-GWEN_ERRORCODE GWEN_I18N_ModuleFini();
+int GWEN_I18N_ModuleInit();
+int GWEN_I18N_ModuleFini();
 
 
+#define I18N(msg) GWEN_I18N_Translate(PACKAGE, msg)
+#define I18S(msg) msg
 
 
 #endif
