@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: inherit_p.h 339 2004-05-05 14:12:27Z cstim $
+    cvs         : $Id: inherit_p.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Sun Dec 05 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -38,7 +38,7 @@ struct GWEN_INHERITDATA {
   GWEN_LIST_ELEMENT(GWEN_INHERITDATA)
   /* No trailing semicolon here because this is a macro call */
 
-  GWEN_TYPE_UINT32 id;
+  uint32_t id;
   void *data;
   void *baseData;
   GWEN_INHERIT_FREEDATAFN freeDataFn;
