@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: list.c 1081 2006-07-16 20:43:11Z martin $
+    cvs         : $Id: list.c 1393 2007-11-22 18:26:05Z martin $
     begin       : Sat Nov 15 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -56,8 +56,8 @@ void GWEN_ListEntry_free(GWEN_LIST_ENTRY *le){
       if (le->usage==0) {
         /* unlink */
         le->previous=0;
-        le->next=0;
-        DBG_DEBUG(GWEN_LOGDOMAIN, "Freeing entry");
+	le->next=0;
+        DBG_VERBOUS(GWEN_LOGDOMAIN, "Freeing entry");
         GWEN_RefPtr_free(le->dataPtr);
         /* really free */
         GWEN_FREE_OBJECT(le);
@@ -319,6 +319,9 @@ unsigned int GWEN_List_GetSize(const GWEN_LIST *l){
   return l->listPtr->size;
 }
 
+int GWEN_List_IsEmpty(const GWEN_LIST *l) {
+  return GWEN_List_GetSize(l) == 0;
+}
 
 
 void GWEN_List_PopBack(GWEN_LIST *l){
@@ -529,8 +532,8 @@ void GWEN_List_Erase(GWEN_LIST *l, GWEN_LIST_ITERATOR *it){
 
 
 
-void GWEN_List_Remove(GWEN_LIST *l, const void *p) {
-  GWEN_LIST_ITERATOR *li;
+GWEN_LIST_ITERATOR *GWEN_List_FindIter(GWEN_LIST *l, const void *p) {
+ GWEN_LIST_ITERATOR *li;
 
   li=GWEN_List_First(l);
   if (li) {
@@ -539,13 +542,33 @@ void GWEN_List_Remove(GWEN_LIST *l, const void *p) {
     d=GWEN_ListIterator_Data(li);
     while(d) {
       if (d==p) {
-        GWEN_List_Erase(l, li);
-        break;
+        return li;
       }
       d=GWEN_ListIterator_Next(li);
     }
     GWEN_ListIterator_free(li);
   }
+  return 0;
+}
+
+const void *GWEN_List_Contains(GWEN_LIST *l, const void *p) {
+  GWEN_LIST_ITERATOR *li;
+
+  li = GWEN_List_FindIter(l, p);
+  if (li) {
+    GWEN_ListIterator_free(li);
+    return p;
+  }
+  return 0;
+}
+
+void GWEN_List_Remove(GWEN_LIST *l, const void *p) {
+  GWEN_LIST_ITERATOR *li;
+
+  li = GWEN_List_FindIter(l, p);
+  if (li) {
+    GWEN_List_Erase(l, li);
+  }
 }
 
 
@@ -778,10 +801,14 @@ const void *GWEN_ConstList_GetBack(GWEN_CONSTLIST *l){
 
 
 
-unsigned int GWEN_ConstList_GetSize(GWEN_CONSTLIST *l){
+unsigned int GWEN_ConstList_GetSize(const GWEN_CONSTLIST *l){
   return GWEN_List_GetSize(l);
 }
 
+int GWEN_ConstList_IsEmpty(const GWEN_LIST *l) {
+  return GWEN_ConstList_GetSize(l) == 0;
+}
+
 
 
 void GWEN_ConstList_PopBack(GWEN_CONSTLIST *l){
@@ -832,6 +859,45 @@ const void *GWEN_ConstList_ForEach(GWEN_CONSTLIST *l,
 
 
 
+GWEN_CONSTLIST_ITERATOR *GWEN_ConstList_FindIter(const GWEN_CONSTLIST *l, const void *p) {
+ GWEN_CONSTLIST_ITERATOR *li;
+
+  li=GWEN_ConstList_First(l);
+  if (li) {
+    const void *d;
+
+    d=GWEN_ConstListIterator_Data(li);
+    while(d) {
+      if (d==p) {
+        return li;
+      }
+      d=GWEN_ConstListIterator_Next(li);
+    }
+    GWEN_ConstListIterator_free(li);
+  }
+  return 0;
+}
+
+const void *GWEN_ConstList_Contains(const GWEN_CONSTLIST *l, const void *p) {
+  GWEN_CONSTLIST_ITERATOR *li;
+
+  li = GWEN_ConstList_FindIter(l, p);
+  if (li) {
+    GWEN_ConstListIterator_free(li);
+    return p;
+  }
+  return 0;
+}
+
+void GWEN_ConstList_Remove(GWEN_CONSTLIST *l, const void *p) {
+  GWEN_CONSTLIST_ITERATOR *li;
+
+  li = GWEN_ConstList_FindIter(l, p);
+  if (li) {
+    GWEN_ConstList_Erase(l, li);
+  }
+}
+
 GWEN_CONSTLIST_ITERATOR *GWEN_ConstList_First(const GWEN_CONSTLIST *l){
   return GWEN_List_First(l);
 }
