@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: list1.c 1048 2006-05-17 17:15:35Z martin $
+    cvs         : $Id: list1.c 1418 2008-03-16 13:50:09Z martin $
     begin       : Sat Nov 15 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -92,8 +92,7 @@ int GWEN_List1_AddList(GWEN_LIST1 *dest, GWEN_LIST1 *l) {
   assert(dest);
   assert(l);
 
-  el=l->firstElement;
-  while(el) {
+  while((el=l->firstElement)) {
     GWEN_List1_Del(el);
     GWEN_List1_Add(dest, el);
   }
@@ -178,6 +177,9 @@ void *GWEN_List1_GetLast(const GWEN_LIST1 *l) {
 
 
 
+
+
+
 GWEN_LIST1_ELEMENT *GWEN_List1Element_new(void *d) {
   GWEN_LIST1_ELEMENT *el;
 
@@ -226,3 +228,5 @@ void *GWEN_List1Element_GetNext(const GWEN_LIST1_ELEMENT *el){
 
 
 
+
+
