@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: list_p.h 651 2004-12-16 17:45:30Z aquamaniac $
+    cvs         : $Id: list_p.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Sat Nov 15 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -55,7 +55,7 @@ struct GWEN_CONSTLIST_ENTRY {
 
 
 struct GWEN__LISTPTR {
-  GWEN_TYPE_UINT32 refCount;
+  uint32_t refCount;
   GWEN_LIST_ENTRY *first;
   GWEN_LIST_ENTRY *last;
   unsigned int size;
