@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: logger_l.h 518 2004-08-20 09:33:36Z aquamaniac $
+    cvs         : $Id: logger_l.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Sun Dec 05 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -31,8 +31,8 @@
 #include <gwenhywfar/logger.h>
 
 
-GWEN_ERRORCODE GWEN_Logger_ModuleInit();
-GWEN_ERRORCODE GWEN_Logger_ModuleFini();
+int GWEN_Logger_ModuleInit();
+int GWEN_Logger_ModuleFini();
 
 
 #endif /* GWEN_LOGGER_L_H */
