@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: logger_p.h 527 2004-08-21 02:52:42Z aquamaniac $
+    cvs         : $Id: logger_p.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Sun Dec 05 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -36,8 +36,13 @@ extern "C" {
 #endif
 
 
+typedef struct GWEN_LOGGER_DOMAIN GWEN_LOGGER_DOMAIN;
+typedef struct GWEN_LOGGER GWEN_LOGGER;
+
+
 struct GWEN_LOGGER {
   GWEN_LOGGER *next;
+  GWEN_LOGGER_DOMAIN *domain;
   int enabled;
   int open;
   GWEN_LOGGER_LOGTYPE logType;
@@ -45,11 +50,10 @@ struct GWEN_LOGGER {
   char *logIdent;
   GWEN_LOGGER_LEVEL logLevel;
   GWEN_LOGGERFUNCTIONLOG logFunction;
-  GWEN_TYPE_UINT32 usage;
+  uint32_t usage;
 };
 
 
-typedef struct GWEN_LOGGER_DOMAIN GWEN_LOGGER_DOMAIN;
 struct GWEN_LOGGER_DOMAIN {
   GWEN_LOGGER_DOMAIN *next;
   char *name;
@@ -72,6 +76,31 @@ int GWEN_Logger__Log(GWEN_LOGGER *lg,
 
 
 
+GWEN_LOGGER *GWEN_Logger_new(GWEN_LOGGER_DOMAIN *domain);
+
+void GWEN_Logger_free(GWEN_LOGGER *lg);
+
+void GWEN_Logger_Attach(GWEN_LOGGER *lg);
+
+
+/**
+ * Adds a logger to the given one. So if the old logger is to log something
+ * then the newly added logger will log the same message as well.
+ * The new logger must already be open (via @ref GWEN_Logger_Open).
+ */
+GWENHYWFAR_API
+void GWEN_Logger_AddLogger(GWEN_LOGGER *oldLogger, GWEN_LOGGER *newLogger);
+
+
+/**
+ * DEPRECATED. Only sets the new default logger if it not already is
+ * set or if the new default logger is NULL.  You must call
+ * GWEN_Logger_Open on that logger prior to calling this function.
+ */
+GWENHYWFAR_API
+void GWEN_Logger_SetDefaultLogger(GWEN_LOGGER *lg) DEPRECATED ;
+
+
 #ifdef __cplusplus
 }
 #endif
