@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: memory.c 1067 2006-05-22 15:25:23Z christian $
+ cvs         : $Id: memory.c 1393 2007-11-22 18:26:05Z martin $
  begin       : Sat Jun 28 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -64,7 +64,7 @@ static size_t gwen_memory__released_since_collect=0;
 
 
 
-GWEN_ERRORCODE GWEN_Memory_ModuleInit(){
+int GWEN_Memory_ModuleInit(){
   const char *s;
 
   s=getenv(GWEN_MEMORY_ENV_DEBUG);
@@ -79,7 +79,7 @@ GWEN_ERRORCODE GWEN_Memory_ModuleInit(){
 
 
 
-GWEN_ERRORCODE GWEN_Memory_ModuleFini(){
+int GWEN_Memory_ModuleFini(){
   GWEN_MEMORY_TABLE *mt;
 
   mt=gwen_memory__first_table;
