@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: memory.h 957 2005-12-23 01:43:18Z aquamaniac $
+ cvs         : $Id: memory.h 1393 2007-11-22 18:26:05Z martin $
  begin       : Sat Jun 28 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -59,10 +59,10 @@ extern "C" {
 
 
   GWENHYWFAR_API 
-  GWEN_ERRORCODE GWEN_Memory_ModuleInit();
+  int GWEN_Memory_ModuleInit();
 
   GWENHYWFAR_API 
-  GWEN_ERRORCODE GWEN_Memory_ModuleFini();
+  int GWEN_Memory_ModuleFini();
 
 
   GWENHYWFAR_API
