@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: memory_l.h 349 2004-05-06 11:02:04Z aquamaniac $
+ cvs         : $Id: memory_l.h 1393 2007-11-22 18:26:05Z martin $
  begin       : Sat Jun 28 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -31,8 +31,8 @@
 
 #include <gwenhywfar/memory.h>
 
-GWEN_ERRORCODE GWEN_Memory_ModuleInit();
-GWEN_ERRORCODE GWEN_Memory_ModuleFini();
+int GWEN_Memory_ModuleInit();
+int GWEN_Memory_ModuleFini();
 
 #endif /* GWENHYWFAR_MEMORY_L_H */
 
