@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: pathmanager_l.h 834 2005-08-17 19:52:39Z aquamaniac $
+    cvs         : $Id: pathmanager_l.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -33,8 +33,8 @@
 #include <gwenhywfar/pathmanager.h>
 
 
-GWEN_ERRORCODE GWEN_PathManager_ModuleInit();
-GWEN_ERRORCODE GWEN_PathManager_ModuleFini();
+int GWEN_PathManager_ModuleInit();
+int GWEN_PathManager_ModuleFini();
 
 
 
