@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: plugin_l.h 621 2004-12-05 20:41:50Z aquamaniac $
+    cvs         : $Id: plugin_l.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Fri Sep 12 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -37,8 +37,8 @@ GWEN_LIST_FUNCTION_DEFS(GWEN_PLUGIN, GWEN_Plugin)
 GWEN_LIST_FUNCTION_DEFS(GWEN_PLUGIN_MANAGER, GWEN_PluginManager)
 
 
-GWEN_ERRORCODE GWEN_Plugin_ModuleInit();
-GWEN_ERRORCODE GWEN_Plugin_ModuleFini();
+int GWEN_Plugin_ModuleInit();
+int GWEN_Plugin_ModuleFini();
 
 void GWEN_Plugin_Attach(GWEN_PLUGIN *p);
 
