@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: plugin_p.h 833 2005-08-17 18:21:48Z aquamaniac $
+    cvs         : $Id: plugin_p.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Fri Sep 12 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -39,7 +39,7 @@ struct GWEN_PLUGIN_MANAGER {
   GWEN_INHERIT_ELEMENT(GWEN_PLUGIN_MANAGER)
   GWEN_LIST_ELEMENT(GWEN_PLUGIN_MANAGER)
   char *name;
-  GWEN_STRINGLIST *paths;
+  char *destLib;
   GWEN_PLUGIN_LIST *plugins;
 };
 
@@ -52,7 +52,7 @@ struct GWEN_PLUGIN {
   char *name;
   char *fileName;
   GWEN_LIBLOADER *libLoader;
-  GWEN_TYPE_UINT32 refCount;
+  uint32_t refCount;
 };
 
 
