@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: plugindescr_p.h,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: plugindescr_p.h,v 1.9 2005/10/04 17:17:55 aquamaniac Exp $
+    cvs         : $Id: plugindescr_p.h 872 2005-10-04 17:17:55Z aquamaniac $
     begin       : Fri Sep 12 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
