@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: refptr_p.h 643 2004-12-15 11:11:16Z aquamaniac $
+    cvs         : $Id: refptr_p.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Sun Jan 25 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -37,8 +37,8 @@ typedef struct GWEN_REFPTR_POBJECT GWEN_REFPTR_POBJECT;
 
 
 struct GWEN_REFPTR_INFO {
-  GWEN_TYPE_UINT32 refCount;
-  GWEN_TYPE_UINT32 flags;
+  uint32_t refCount;
+  uint32_t flags;
   GWEN_REFPTR_INFO_FREE_FN freeFn;
   GWEN_REFPTR_INFO_DUP_FN dupFn;
 };
@@ -46,8 +46,8 @@ struct GWEN_REFPTR_INFO {
 
 
 struct GWEN_REFPTR_POBJECT {
-  GWEN_TYPE_UINT32 refCount;
-  GWEN_TYPE_UINT32 flags;
+  uint32_t refCount;
+  uint32_t flags;
   GWEN_REFPTR_INFO *infoPtr;
   void *ptr;
 };
