@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: ringbuffer_p.h 225 2004-01-25 09:01:37Z aquamaniac $
+    cvs         : $Id: ringbuffer_p.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Sun Jan 25 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -36,14 +36,14 @@
 
 struct GWEN_RINGBUFFER {
   char *ptr;
-  GWEN_TYPE_UINT32 bufferSize;
-  GWEN_TYPE_UINT32 readPos;
-  GWEN_TYPE_UINT32 writePos;
-  GWEN_TYPE_UINT32 bytesUsed;
-  GWEN_TYPE_UINT32 maxBytesUsed;
-  GWEN_TYPE_UINT32 emptyCounter;
-  GWEN_TYPE_UINT32 fullCounter;
-  GWEN_TYPE_UINT32 throughput;
+  uint32_t bufferSize;
+  uint32_t readPos;
+  uint32_t writePos;
+  uint32_t bytesUsed;
+  uint32_t maxBytesUsed;
+  uint32_t emptyCounter;
+  uint32_t fullCounter;
+  uint32_t throughput;
 };
 
 
