@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: stringlist_p.h 786 2005-07-09 13:38:17Z aquamaniac $
+ cvs         : $Id: stringlist_p.h 1393 2007-11-22 18:26:05Z martin $
  begin       : Thu Apr 03 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -36,7 +36,7 @@
 struct GWEN_STRINGLISTENTRYSTRUCT {
   GWEN_STRINGLISTENTRY *next;
   const char *data;
-  GWEN_TYPE_UINT32 refCount;
+  uint32_t refCount;
 };
 
 
