@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: bufferedio.c 1067 2006-05-22 15:25:23Z christian $
+ cvs         : $Id: bufferedio.c 1393 2007-11-22 18:26:05Z martin $
  begin       : Fri Feb 07 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -37,7 +37,8 @@
 #include "i18n_l.h"
 #include <gwenhywfar/misc.h>
 #include <gwenhywfar/text.h>
-#include <gwenhywfar/waitcallback.h>
+#include <gwenhywfar/gui.h>
+
 #include <stdlib.h>
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
@@ -51,77 +52,6 @@
 GWEN_INHERIT_FUNCTIONS(GWEN_BUFFEREDIO)
 
 
-const char *GWEN_BufferedIO_ErrorString(int c){
-  const char *s;
-
-  switch(c) {
-  case GWEN_BUFFEREDIO_ERROR_READ:
-    s="Error on read";
-    break;
-  case GWEN_BUFFEREDIO_ERROR_WRITE:
-    s="Error on write";
-    break;
-  case GWEN_BUFFEREDIO_ERROR_CLOSE:
-    s="Error on write";
-    break;
-  case GWEN_BUFFEREDIO_ERROR_TIMEOUT:
-    s="Transaction timout";
-    break;
-  case GWEN_BUFFEREDIO_ERROR_EOF:
-    s="EOF met";
-    break;
-  case GWEN_BUFFEREDIO_ERROR_NO_DATA:
-    s="Could not read/write data";
-    break;
-  case GWEN_BUFFEREDIO_ERROR_PARTIAL:
-    s="Partial data read/written";
-    break;
-  default:
-    s=0;
-  } /* switch */
-
-  return s;
-}
-
-
-
-static int gwen_bufferedio_is_initialized=0;
-static GWEN_ERRORTYPEREGISTRATIONFORM *gwen_bufferedio_errorform=0;
-
-
-
-GWEN_ERRORCODE GWEN_BufferedIO_ModuleInit(){
-  if (!gwen_bufferedio_is_initialized) {
-    GWEN_ERRORCODE err;
-
-    gwen_bufferedio_errorform=GWEN_ErrorType_new();
-    GWEN_ErrorType_SetName(gwen_bufferedio_errorform,
-                           GWEN_BUFFEREDIO_ERROR_TYPE);
-    GWEN_ErrorType_SetMsgPtr(gwen_bufferedio_errorform,
-                             GWEN_BufferedIO_ErrorString);
-    err=GWEN_Error_RegisterType(gwen_bufferedio_errorform);
-    if (!GWEN_Error_IsOk(err))
-      return err;
-    gwen_bufferedio_is_initialized=1;
-  }
-  return 0;
-}
-
-
-
-GWEN_ERRORCODE GWEN_BufferedIO_ModuleFini(){
-  if (gwen_bufferedio_is_initialized) {
-    GWEN_ERRORCODE err;
-
-    err=GWEN_Error_UnregisterType(gwen_bufferedio_errorform);
-    GWEN_ErrorType_free(gwen_bufferedio_errorform);
-    if (!GWEN_Error_IsOk(err))
-      return err;
-    gwen_bufferedio_is_initialized=0;
-  }
-  return 0;
-}
-
 
 
 GWEN_BUFFEREDIO *GWEN_BufferedIO_new(){
@@ -197,7 +127,7 @@ int GWEN_BufferedIO_CheckEOF(GWEN_BUFFEREDIO *bt){
 
 
 int GWEN_BufferedIO__FillReadBuffer(GWEN_BUFFEREDIO *bt){
-  GWEN_ERRORCODE err;
+  int err;
   int i;
 
   assert(bt->readPtr);
@@ -206,17 +136,18 @@ int GWEN_BufferedIO__FillReadBuffer(GWEN_BUFFEREDIO *bt){
                   bt->readerBuffer,
                   &i,
                   bt->timeout);
-  if (!GWEN_Error_IsOk(err)) {
-    if (GWEN_Error_GetType(err)==
-        GWEN_Error_FindType(GWEN_BUFFEREDIO_ERROR_TYPE) &&
-        GWEN_Error_GetCode(err)==GWEN_BUFFEREDIO_ERROR_NO_DATA) {
+  if (err) {
+    if (err==GWEN_ERROR_NO_DATA) {
       DBG_INFO(GWEN_LOGDOMAIN, "Could not fill input buffer, no data");
       return GWEN_BUFFEREDIO_CHAR_NO_DATA;
     }
-    DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
-    bt->readerError=1;
-    return GWEN_BUFFEREDIO_CHAR_ERROR;
+    else {
+      DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
+      bt->readerError=1;
+      return GWEN_BUFFEREDIO_CHAR_ERROR;
+    }
   }
+
   bt->readerBufferFilled=i;
   bt->readerBufferPos=0;
   bt->readerEOF=(i==0);
@@ -232,13 +163,16 @@ int GWEN_BufferedIO__FillReadBuffer(GWEN_BUFFEREDIO *bt){
 
 
 int GWEN_BufferedIO_PeekChar(GWEN_BUFFEREDIO *bt){
+  unsigned char c;
+
   assert(bt);
 
   /* Extend the assertion: If it fails, print a more verbose error
      message to help programmers who are inexperienced with the
      BUFFEREDIO. */
   if (!bt->readerBuffer) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "BufferedIO has not yet been assigned a reading buffer for reading; probably assign one by GWEN_BufferedIO_SetReadBuffer(bio,0,length).");
+    DBG_ERROR(GWEN_LOGDOMAIN,
+	      "BufferedIO has not yet been assigned a reading buffer for reading; probably assign one by GWEN_BufferedIO_SetReadBuffer(bio,0,length).");
     assert(bt->readerBuffer);
   }
 
@@ -258,7 +192,17 @@ int GWEN_BufferedIO_PeekChar(GWEN_BUFFEREDIO *bt){
     if (rv)
       return rv;
   }
-  return (unsigned char)(bt->readerBuffer[bt->readerBufferPos]);
+
+  c=(bt->readerBuffer[bt->readerBufferPos]);
+  if (bt->flags & GWEN_BUFFEREDIO_FLAGS_UNTIL_EMPTY_LINE) {
+    if (c==10 && bt->filteredLinePos==0) {
+      bt->readerBufferPos++;
+      bt->lines++;
+      bt->linePos=0;
+      return GWEN_BUFFEREDIO_CHAR_EOF;
+    }
+  }
+  return c;
 }
 
 
@@ -287,13 +231,26 @@ int GWEN_BufferedIO_ReadChar(GWEN_BUFFEREDIO *bt){
     if (rv)
       return rv;
   }
+
   i=(unsigned char)(bt->readerBuffer[bt->readerBufferPos++]);
   if (i==GWEN_BUFFEREDIO_LF) {
     bt->lines++;
     bt->linePos=0;
+    if ((bt->flags & GWEN_BUFFEREDIO_FLAGS_UNTIL_EMPTY_LINE) &&
+	bt->filteredLinePos==0) {
+      bt->filteredLinePos=0;
+      DBG_DEBUG(GWEN_LOGDOMAIN, "Empty line, EOF");
+      return GWEN_BUFFEREDIO_CHAR_EOF;
+    }
+    else {
+      bt->filteredLinePos=0;
+    }
   }
-  else
+  else {
     bt->linePos++;
+    if (i!=GWEN_BUFFEREDIO_CR)
+      bt->filteredLinePos++;
+  }
   bt->bytesRead++;
 
   return i;
@@ -301,8 +258,8 @@ int GWEN_BufferedIO_ReadChar(GWEN_BUFFEREDIO *bt){
 
 
 
-GWEN_ERRORCODE GWEN_BufferedIO_Flush(GWEN_BUFFEREDIO *bt){
-  GWEN_ERRORCODE err;
+int GWEN_BufferedIO_Flush(GWEN_BUFFEREDIO *bt){
+  int err;
   int i;
   int written;
 
@@ -321,10 +278,8 @@ GWEN_ERRORCODE GWEN_BufferedIO_Flush(GWEN_BUFFEREDIO *bt){
 		     &(bt->writerBuffer[written]),
 		     &i,
 		     bt->timeout);
-    if (!GWEN_Error_IsOk(err)) {
-      DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
+    if (err)
       return err;
-    }
     written+=i;
   } /* while */
 
@@ -336,8 +291,8 @@ GWEN_ERRORCODE GWEN_BufferedIO_Flush(GWEN_BUFFEREDIO *bt){
 
 
 
-GWEN_ERRORCODE GWEN_BufferedIO_ShortFlush(GWEN_BUFFEREDIO *bt){
-  GWEN_ERRORCODE err;
+int GWEN_BufferedIO_ShortFlush(GWEN_BUFFEREDIO *bt){
+  int err;
   int i;
 
   assert(bt);
@@ -353,17 +308,14 @@ GWEN_ERRORCODE GWEN_BufferedIO_ShortFlush(GWEN_BUFFEREDIO *bt){
 		   &(bt->writerBuffer[bt->writerBufferFlushPos]),
 		   &i,
 		   bt->timeout);
-  if (!GWEN_Error_IsOk(err)) {
-    DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
+  if (err) {
+    DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
     return err;
   }
   if (i<bt->writerBufferFilled-bt->writerBufferFlushPos) {
     /* partial flush */
     bt->writerBufferFlushPos+=i;
-    return GWEN_Error_new(0,
-			  GWEN_ERROR_SEVERITY_WARN,
-			  GWEN_Error_FindType(GWEN_BUFFEREDIO_ERROR_TYPE),
-			  GWEN_BUFFEREDIO_ERROR_PARTIAL);
+    return GWEN_ERROR_PARTIAL;
   }
   else {
     /* all bytes written, flush finished */
@@ -394,17 +346,17 @@ int GWEN_BufferedIO_WriteBufferEmpty(GWEN_BUFFEREDIO *bt) {
 
 
 
-GWEN_ERRORCODE GWEN_BufferedIO_WriteChar(GWEN_BUFFEREDIO *bt, char c){
+int GWEN_BufferedIO_WriteChar(GWEN_BUFFEREDIO *bt, char c){
   assert(bt);
   assert(bt->writerBuffer);
 
   /* flush buffer if needed (only needed if last flush attempt failed) */
   if (bt->writerBufferFilled>=bt->writerBufferLength) {
-    GWEN_ERRORCODE err;
+    int err;
 
     err=GWEN_BufferedIO_Flush(bt);
-    if (!GWEN_Error_IsOk(err)) {
-      DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
+    if (err) {
+      DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
       return err;
     }
   }
@@ -423,11 +375,11 @@ GWEN_ERRORCODE GWEN_BufferedIO_WriteChar(GWEN_BUFFEREDIO *bt, char c){
 
   /* flush buffer if needed */
   if (bt->writerBufferFilled>=bt->writerBufferLength) {
-    GWEN_ERRORCODE err;
+    int err;
 
     err=GWEN_BufferedIO_Flush(bt);
-    if (!GWEN_Error_IsOk(err)) {
-      DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
+    if (err) {
+      DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
       return err;
     }
   }
@@ -436,8 +388,8 @@ GWEN_ERRORCODE GWEN_BufferedIO_WriteChar(GWEN_BUFFEREDIO *bt, char c){
 
 
 
-GWEN_ERRORCODE GWEN_BufferedIO_Close(GWEN_BUFFEREDIO *bt){
-  GWEN_ERRORCODE err, err2;
+int GWEN_BufferedIO_Close(GWEN_BUFFEREDIO *bt){
+  int err, err2;
 
   assert(bt);
   assert(bt->closePtr);
@@ -447,12 +399,12 @@ GWEN_ERRORCODE GWEN_BufferedIO_Close(GWEN_BUFFEREDIO *bt){
   else
     err2=0;
 
-  if (!GWEN_Error_IsOk(err)) {
-    DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
+  if (err) {
+    DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
     return err;
   }
-  if (!GWEN_Error_IsOk(err2)) {
-    DBG_ERROR_ERR(GWEN_LOGDOMAIN, err2);
+  if (err2) {
+    DBG_INFO_ERR(GWEN_LOGDOMAIN, err2);
     return err2;
   }
   return 0;
@@ -460,14 +412,14 @@ GWEN_ERRORCODE GWEN_BufferedIO_Close(GWEN_BUFFEREDIO *bt){
 
 
 
-GWEN_ERRORCODE GWEN_BufferedIO_Abandon(GWEN_BUFFEREDIO *bt){
-  GWEN_ERRORCODE err;
+int GWEN_BufferedIO_Abandon(GWEN_BUFFEREDIO *bt){
+  int err;
 
   assert(bt);
   assert(bt->closePtr);
   err=bt->closePtr(bt);
-  if (!GWEN_Error_IsOk(err)) {
-    DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
+  if (err) {
+    DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
     return err;
   }
   return 0;
@@ -475,9 +427,9 @@ GWEN_ERRORCODE GWEN_BufferedIO_Abandon(GWEN_BUFFEREDIO *bt){
 
 
 
-GWEN_ERRORCODE GWEN_BufferedIO_ReadLine(GWEN_BUFFEREDIO *bt,
-                                        char *buffer,
-                                        unsigned int s){
+int GWEN_BufferedIO_ReadLine(GWEN_BUFFEREDIO *bt,
+			     char *buffer,
+			     unsigned int s){
   int c;
   int pos;
 
@@ -496,10 +448,7 @@ GWEN_ERRORCODE GWEN_BufferedIO_ReadLine(GWEN_BUFFEREDIO *bt,
     }
     if (c<0) {
       DBG_ERROR(GWEN_LOGDOMAIN, "Error while reading");
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_BUFFEREDIO_ERROR_TYPE),
-                            GWEN_BUFFEREDIO_ERROR_READ);
+      return GWEN_ERROR_READ;
     }
 
     if (c==GWEN_BUFFEREDIO_LF) {
@@ -525,8 +474,8 @@ GWEN_ERRORCODE GWEN_BufferedIO_ReadLine(GWEN_BUFFEREDIO *bt,
 
 
 
-GWEN_ERRORCODE GWEN_BufferedIO_ReadLine2Buffer(GWEN_BUFFEREDIO *bt,
-                                               GWEN_BUFFER *buffer) {
+int GWEN_BufferedIO_ReadLine2Buffer(GWEN_BUFFEREDIO *bt,
+				    GWEN_BUFFER *buffer) {
   int c;
 
   /* now read */
@@ -541,10 +490,7 @@ GWEN_ERRORCODE GWEN_BufferedIO_ReadLine2Buffer(GWEN_BUFFEREDIO *bt,
     }
     if (c<0) {
       DBG_ERROR(GWEN_LOGDOMAIN, "Error while reading");
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_BUFFEREDIO_ERROR_TYPE),
-                            GWEN_BUFFEREDIO_ERROR_READ);
+      return GWEN_ERROR_READ;
     }
 
     if (c==GWEN_BUFFEREDIO_LF) {
@@ -563,16 +509,15 @@ GWEN_ERRORCODE GWEN_BufferedIO_ReadLine2Buffer(GWEN_BUFFEREDIO *bt,
 
 
 
-GWEN_ERRORCODE GWEN_BufferedIO_Write(GWEN_BUFFEREDIO *bt,
-                                     const char *buffer){
-  GWEN_ERRORCODE err;
+int GWEN_BufferedIO_Write(GWEN_BUFFEREDIO *bt, const char *buffer){
+  int err;
 
   assert(bt);
   assert(buffer);
   while(*buffer) {
     err=GWEN_BufferedIO_WriteChar(bt, *buffer);
-    if (!GWEN_Error_IsOk(err)) {
-      DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
+    if (err) {
+      DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
       return err;
     }
     buffer++;
@@ -582,33 +527,32 @@ GWEN_ERRORCODE GWEN_BufferedIO_Write(GWEN_BUFFEREDIO *bt,
 
 
 
-GWEN_ERRORCODE GWEN_BufferedIO_WriteLine(GWEN_BUFFEREDIO *bt,
-                                         const char *buffer){
-  GWEN_ERRORCODE err;
+int GWEN_BufferedIO_WriteLine(GWEN_BUFFEREDIO *bt, const char *buffer){
+  int err;
 
   assert(bt);
   assert(buffer);
   err=GWEN_BufferedIO_Write(bt, buffer);
-  if (!GWEN_Error_IsOk(err)) {
-    DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
+  if (err) {
+    DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
     return err;
   }
   if (bt->lineMode==GWEN_LineModeDOS) {
     err=GWEN_BufferedIO_WriteChar(bt, GWEN_BUFFEREDIO_CR);
-    if (!GWEN_Error_IsOk(err)) {
-      DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
+    if (err) {
+      DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
       return err;
     }
   }
   err=GWEN_BufferedIO_WriteChar(bt, GWEN_BUFFEREDIO_LF);
-  if (!GWEN_Error_IsOk(err)) {
-    DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
+  if (err) {
+    DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
     return err;
   }
 
   err=GWEN_BufferedIO_Flush(bt);
-  if (!GWEN_Error_IsOk(err)) {
-    DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
+  if (err) {
+    DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
     return err;
   }
 
@@ -646,11 +590,11 @@ int GWEN_BufferedIO_GetTimeout(const GWEN_BUFFEREDIO *dm){
 
 
 
-GWEN_ERRORCODE GWEN_BufferedIO_WriteRaw(GWEN_BUFFEREDIO *bt,
-                                        const char *buffer,
-                                        unsigned int *bsize){
+int GWEN_BufferedIO_WriteRaw(GWEN_BUFFEREDIO *bt,
+			     const char *buffer,
+			     unsigned int *bsize){
 
-  GWEN_ERRORCODE err;
+  int err;
   int i;
 
   assert(bt);
@@ -660,16 +604,16 @@ GWEN_ERRORCODE GWEN_BufferedIO_WriteRaw(GWEN_BUFFEREDIO *bt,
   if (bt->writerBufferFilled) {
     /* some data in the buffer, this must be flushed first */
     err=GWEN_BufferedIO_ShortFlush(bt);
-    if (!GWEN_Error_IsOk(err)) {
-      DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
-      return err;
-    }
-    if (GWEN_Error_GetType(err)==
-        GWEN_Error_FindType(GWEN_BUFFEREDIO_ERROR_TYPE) &&
-        GWEN_Error_GetCode(err)==GWEN_BUFFEREDIO_ERROR_PARTIAL) {
-      /* still some bytes in the buffer, can not write right now */
-      *bsize=0;
-      return err;
+    if (err) {
+      if (err!=GWEN_ERROR_PARTIAL) {
+        DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
+	return err;
+      }
+      else {
+	/* still some bytes in the buffer, can not write right now */
+	*bsize=0;
+	return err;
+      }
     }
   }
 
@@ -679,37 +623,31 @@ GWEN_ERRORCODE GWEN_BufferedIO_WriteRaw(GWEN_BUFFEREDIO *bt,
                    buffer,
                    &i,
                    bt->timeout);
-  if (!GWEN_Error_IsOk(err)) {
-    DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
+  if (err) {
+    DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
     return err;
   }
   *bsize=i;
   bt->bytesWritten+=i;
 
-  return err;
+  return 0;
 }
 
 
 
-GWEN_ERRORCODE GWEN_BufferedIO_ReadRaw(GWEN_BUFFEREDIO *bt,
-                                       char *buffer,
-                                       unsigned int *bsize){
+int GWEN_BufferedIO_ReadRaw(GWEN_BUFFEREDIO *bt,
+			    char *buffer,
+			    unsigned int *bsize){
   assert(bt);
 
   /* do some fast checks */
   if (bt->readerError) {
     DBG_INFO(GWEN_LOGDOMAIN, "Error flagged");
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_BUFFEREDIO_ERROR_TYPE),
-                          GWEN_BUFFEREDIO_ERROR_READ);
+    return GWEN_ERROR_READ;
   }
   if (bt->readerEOF) {
     DBG_INFO(GWEN_LOGDOMAIN, "EOF flagged");
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_BUFFEREDIO_ERROR_TYPE),
-                          GWEN_BUFFEREDIO_ERROR_READ);
+    return GWEN_ERROR_EOF;
   }
 
   if (bt->readerBufferPos<bt->readerBufferFilled) {
@@ -734,7 +672,7 @@ GWEN_ERRORCODE GWEN_BufferedIO_ReadRaw(GWEN_BUFFEREDIO *bt,
   }
   else {
     /* buffer empty, so read directly from source */
-    GWEN_ERRORCODE err;
+    int err;
     int i;
 
     DBG_DEBUG(GWEN_LOGDOMAIN, "Reading directly from source");
@@ -744,8 +682,8 @@ GWEN_ERRORCODE GWEN_BufferedIO_ReadRaw(GWEN_BUFFEREDIO *bt,
                     buffer,
                     &i,
                     bt->timeout);
-    if (!GWEN_Error_IsOk(err)) {
-      DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
+    if (err) {
+      DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
       bt->readerError=1;
       return err;
     }
@@ -756,65 +694,64 @@ GWEN_ERRORCODE GWEN_BufferedIO_ReadRaw(GWEN_BUFFEREDIO *bt,
   }
   if (bt->readerEOF) {
     DBG_DEBUG(GWEN_LOGDOMAIN, "EOF now met");
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_WARN,
-                          GWEN_Error_FindType(GWEN_BUFFEREDIO_ERROR_TYPE),
-                          GWEN_BUFFEREDIO_ERROR_EOF);
+    return GWEN_ERROR_EOF;
   }
   return 0;
 }
 
 
 
-GWEN_ERRORCODE GWEN_BufferedIO_ReadRawForced(GWEN_BUFFEREDIO *bt,
-                                             char *buffer,
-                                             unsigned int *bsize){
-  GWEN_ERRORCODE err;
+int GWEN_BufferedIO_ReadRawForced(GWEN_BUFFEREDIO *bt,
+				  char *buffer,
+				  unsigned int *bsize){
+  int err;
   char *lbuffer;
   unsigned int lsize;
   unsigned int bytesRead;
-  GWEN_WAITCALLBACK_RESULT cbres;
+  uint32_t progressId;
 
   lbuffer=buffer;
   bytesRead=0;
 
-  GWEN_WaitCallback_EnterWithText(GWEN_WAITCALLBACK_ID_FAST,
-                                  I18N("Reading from buffered IO..."),
-                                  I18N("byte(s)"),
-                                  0);
-  GWEN_WaitCallback_SetProgressTotal(*bsize);
+  progressId=GWEN_Gui_ProgressStart(GWEN_GUI_PROGRESS_DELAY |
+				    GWEN_GUI_PROGRESS_ALLOW_EMBED |
+				    GWEN_GUI_PROGRESS_SHOW_PROGRESS |
+				    GWEN_GUI_PROGRESS_SHOW_ABORT,
+				    I18N("Reading from buffered IO..."),
+				    NULL,
+				    *bsize, 0);
+
   while(bytesRead<*bsize) {
-    cbres=GWEN_WaitCallbackProgress(bytesRead);
-    if (cbres==GWEN_WaitCallbackResult_Abort) {
-      DBG_ERROR(GWEN_LOGDOMAIN, "User abort");
+    err=GWEN_Gui_ProgressAdvance(progressId, bytesRead);
+    if (err) {
+      DBG_INFO(GWEN_LOGDOMAIN, "User abort");
       *bsize=bytesRead;
-      GWEN_WaitCallback_Leave();
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_BUFFEREDIO_ERROR_TYPE),
-                            GWEN_BUFFEREDIO_ERROR_PARTIAL);
+      GWEN_Gui_ProgressEnd(progressId);
+      return err;
     }
     lsize=*bsize-bytesRead;
     err=GWEN_BufferedIO_ReadRaw(bt, lbuffer, &lsize);
-    if (!GWEN_Error_IsOk(err)) {
-      DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
+    if (err) {
+      DBG_INFO_ERR(GWEN_LOGDOMAIN, err);
       *bsize=bytesRead;
-      GWEN_WaitCallback_Leave();
+      GWEN_Gui_ProgressEnd(progressId);
       return err;
     }
     if (lsize==0) {
+      err=GWEN_Gui_ProgressLog(progressId,
+			       GWEN_LoggerLevel_Error,
+			       I18N("Premature end of stream"));
       DBG_ERROR(GWEN_LOGDOMAIN, "Premature end of stream");
       *bsize=bytesRead;
-      GWEN_WaitCallback_Leave();
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_BUFFEREDIO_ERROR_TYPE),
-                            GWEN_BUFFEREDIO_ERROR_PARTIAL);
+      GWEN_Gui_ProgressEnd(progressId);
+      if (err==GWEN_ERROR_USER_ABORTED)
+        return err;
+      return GWEN_ERROR_PARTIAL;
     }
     bytesRead+=lsize;
     lbuffer+=lsize;
   } /* while */
-  GWEN_WaitCallback_Leave();
+  GWEN_Gui_ProgressEnd(progressId);
 
   /* no need to update bsize here, because it already contains the correct
    * value */
@@ -823,54 +760,51 @@ GWEN_ERRORCODE GWEN_BufferedIO_ReadRawForced(GWEN_BUFFEREDIO *bt,
 
 
 
-GWEN_ERRORCODE GWEN_BufferedIO_WriteRawForced(GWEN_BUFFEREDIO *bt,
-                                              const char *buffer,
-                                              unsigned int *bsize){
-  GWEN_ERRORCODE err;
+int GWEN_BufferedIO_WriteRawForced(GWEN_BUFFEREDIO *bt,
+				   const char *buffer,
+				   unsigned int *bsize){
+  int err;
   const char *lbuffer;
   unsigned int lsize;
   unsigned int bytesWritten;
-  GWEN_WAITCALLBACK_RESULT cbres;
+  uint32_t progressId;
 
   lbuffer=buffer;
   bytesWritten=0;
 
-  GWEN_WaitCallback_EnterWithText(GWEN_WAITCALLBACK_ID_FAST,
-                                  I18N("Writing to buffered IO..."),
-                                  I18N("byte(s)"),
-                                  0);
-  GWEN_WaitCallback_SetProgressTotal(*bsize);
+  progressId=GWEN_Gui_ProgressStart(GWEN_GUI_PROGRESS_DELAY |
+				    GWEN_GUI_PROGRESS_ALLOW_EMBED |
+				    GWEN_GUI_PROGRESS_SHOW_PROGRESS |
+				    GWEN_GUI_PROGRESS_SHOW_ABORT,
+				    I18N("Writing to buffered IO..."),
+				    NULL,
+				    *bsize, 0);
   while(bytesWritten<*bsize) {
-    cbres=GWEN_WaitCallbackProgress(bytesWritten);
-    if (cbres==GWEN_WaitCallbackResult_Abort) {
-      DBG_ERROR(GWEN_LOGDOMAIN, "User abort");
+    err=GWEN_Gui_ProgressAdvance(progressId, bytesWritten);
+    if (err) {
+      DBG_INFO(GWEN_LOGDOMAIN, "User aborted");
       *bsize=bytesWritten;
-      GWEN_WaitCallback_Leave();
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_BUFFEREDIO_ERROR_TYPE),
-                            GWEN_BUFFEREDIO_ERROR_PARTIAL);
+      GWEN_Gui_ProgressEnd(progressId);
+      return err;
     }
+
     lsize=*bsize-bytesWritten;
     err=GWEN_BufferedIO_WriteRaw(bt, lbuffer, &lsize);
-    if (!GWEN_Error_IsOk(err)) {
+    if (err) {
       DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
-      GWEN_WaitCallback_Leave();
+      GWEN_Gui_ProgressEnd(progressId);
       return err;
     }
     if (lsize==0) {
       DBG_ERROR(GWEN_LOGDOMAIN, "Broken pipe");
       *bsize=bytesWritten;
-      GWEN_WaitCallback_Leave();
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_BUFFEREDIO_ERROR_TYPE),
-                            GWEN_BUFFEREDIO_ERROR_PARTIAL);
+      GWEN_Gui_ProgressEnd(progressId);
+      return GWEN_ERROR_PARTIAL;
     }
     bytesWritten+=lsize;
     lbuffer+=lsize;
   } /* while */
-  GWEN_WaitCallback_Leave();
+  GWEN_Gui_ProgressEnd(progressId);
 
   return 0;
 
@@ -879,28 +813,28 @@ GWEN_ERRORCODE GWEN_BufferedIO_WriteRawForced(GWEN_BUFFEREDIO *bt,
 
 
 
-GWEN_TYPE_UINT32 GWEN_BufferedIO_GetFlags(const GWEN_BUFFEREDIO *bt) {
+uint32_t GWEN_BufferedIO_GetFlags(const GWEN_BUFFEREDIO *bt) {
   assert(bt);
   return bt->flags;
 }
 
 
 
-void GWEN_BufferedIO_SetFlags(GWEN_BUFFEREDIO *bt, GWEN_TYPE_UINT32 f) {
+void GWEN_BufferedIO_SetFlags(GWEN_BUFFEREDIO *bt, uint32_t f) {
   assert(bt);
   bt->flags=f;
 }
 
 
 
-void GWEN_BufferedIO_AddFlags(GWEN_BUFFEREDIO *bt, GWEN_TYPE_UINT32 f) {
+void GWEN_BufferedIO_AddFlags(GWEN_BUFFEREDIO *bt, uint32_t f) {
   assert(bt);
   bt->flags|=f;
 }
 
 
 
-void GWEN_BufferedIO_SubFlags(GWEN_BUFFEREDIO *bt, GWEN_TYPE_UINT32 f) {
+void GWEN_BufferedIO_SubFlags(GWEN_BUFFEREDIO *bt, uint32_t f) {
   assert(bt);
   bt->flags&=~f;
 }
