@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: bufferedio_l.h 349 2004-05-06 11:02:04Z aquamaniac $
+ cvs         : $Id: bufferedio_l.h 1393 2007-11-22 18:26:05Z martin $
  begin       : Fri Feb 07 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -32,11 +32,8 @@
 #include <gwenhywfar/bufferedio.h>
 
 
-GWEN_ERRORCODE GWEN_BufferedIO_ModuleInit();
-GWEN_ERRORCODE GWEN_BufferedIO_ModuleFini();
 
-
-#endif /* GWENHYWFAR_BUFFEREDIO_P_H */
+#endif /* GWENHYWFAR_BUFFEREDIO_L_H */
 
 
 
