@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: ipc.c 932 2005-11-22 01:09:26Z aquamaniac $
+    cvs         : $Id: ipc.c 1393 2007-11-22 18:26:05Z martin $
     begin       : Fri May 07 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -18,8 +18,10 @@
 
 #include "ipc_p.h"
 #include <gwenhywfar/debug.h>
-#include <gwenhywfar/nl_packets.h>
-#include <gwenhywfar/net2.h>
+#include <gwenhywfar/io_packets.h>
+#include <gwenhywfar/iomanager.h>
+#include <gwenhywfar/text.h>
+
 
 
 GWEN_LIST_FUNCTIONS(GWEN_IPCNODE, GWEN_IpcNode)
@@ -27,7 +29,7 @@ GWEN_LIST_FUNCTIONS(GWEN_IPCMSG, GWEN_IpcMsg)
 GWEN_LIST_FUNCTIONS(GWEN_IPC__REQUEST, GWEN_Ipc__Request)
 
 
-static GWEN_TYPE_UINT32 gwen_ipc__lastid=0;
+static uint32_t gwen_ipc__lastid=0;
 
 
 /* _________________________________________________________________________
@@ -60,7 +62,7 @@ void GWEN_IpcNode_free(GWEN_IPCNODE *n){
     DBG_MEM_DEC("GWEN_IPCNODE");
     assert(n->usage);
     if (--(n->usage)==0) {
-      GWEN_NetLayer_free(n->netLayer);
+      GWEN_Io_Layer_free(n->ioLayer);
       GWEN_LIST_FINI(GWEN_IPCNODE, n);
       GWEN_FREE_OBJECT(n);
     }
@@ -145,7 +147,7 @@ GWEN_IPCMSG *GWEN_IpcMsg_new(GWEN_IPCNODE *n){
 void GWEN_IpcMsg_free(GWEN_IPCMSG *m){
   if (m) {
     DBG_MEM_DEC("GWEN_IPCMSG");
-    GWEN_NL_Packet_free(m->packet);
+    GWEN_Io_Request_free(m->packet);
     GWEN_IpcNode_free(m->node);
     GWEN_DB_Group_free(m->db);
     GWEN_LIST_FINI(GWEN_IPCMSG, m);
@@ -270,8 +272,8 @@ void GWEN_Ipc__Request_AddResponseMsg(GWEN_IPC__REQUEST *r, GWEN_IPCMSG *m){
 
 /* -------------------------------------------------------------- FUNCTION */
 int GWEN_Ipc__Request_HasRequestMsg(GWEN_IPC__REQUEST *r,
-				    GWEN_TYPE_UINT32 nid,
-				    GWEN_TYPE_UINT32 id){
+				    uint32_t nid,
+				    uint32_t id){
   GWEN_IPCMSG *m;
 
   assert(r);
@@ -412,25 +414,33 @@ void GWEN_IpcManager_SetApplicationName(GWEN_IPCMANAGER *mgr,
 
 
 /* -------------------------------------------------------------- FUNCTION */
-GWEN_TYPE_UINT32 GWEN_IpcManager_AddServer(GWEN_IPCMANAGER *mgr,
-					   GWEN_NETLAYER *nlBase,
-                                           GWEN_TYPE_UINT32 mark){
+uint32_t GWEN_IpcManager_AddServer(GWEN_IPCMANAGER *mgr,
+				   GWEN_IO_LAYER *ioBase,
+				   uint32_t mark){
   GWEN_IPCNODE *n;
-  GWEN_NETLAYER *nl;
+  GWEN_IO_LAYER *io;
   int rv;
 
   /* create connection layer */
-  nl=GWEN_NetLayerPackets_new(nlBase);
-  GWEN_Net_AddConnectionToPool(nl);
-  rv=GWEN_NetLayer_Listen(nl);
+  io=GWEN_Io_LayerPackets_new(ioBase);
+  assert(io);
+  rv=GWEN_Io_Manager_RegisterLayer(io);
   if (rv<0) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Could not start server (%d)", rv);
-    GWEN_NetLayer_free(nl);
+    DBG_INFO(GWEN_LOGDOMAIN, "Could not register io layer (%d)", rv);
+    GWEN_Io_Layer_free(io);
+    return 0;
+  }
+
+  /* go into listening state */
+  rv=GWEN_Io_Layer_ListenRecursively(io, NULL);
+  if (rv<0) {
+    DBG_INFO(GWEN_LOGDOMAIN, "Could not start listening (%d)", rv);
+    GWEN_Io_Layer_free(io);
     return 0;
   }
 
   n=GWEN_IpcNode_new();
-  n->netLayer=nl;
+  n->ioLayer=io;
   n->mark=mark;
   n->isServer=1;
   GWEN_IpcNode_List_Add(n, mgr->nodes);
@@ -440,18 +450,25 @@ GWEN_TYPE_UINT32 GWEN_IpcManager_AddServer(GWEN_IPCMANAGER *mgr,
 
 
 /* -------------------------------------------------------------- FUNCTION */
-GWEN_TYPE_UINT32 GWEN_IpcManager_AddClient(GWEN_IPCMANAGER *mgr,
-					   GWEN_NETLAYER *nlBase,
-					   GWEN_TYPE_UINT32 mark){
+uint32_t GWEN_IpcManager_AddClient(GWEN_IPCMANAGER *mgr,
+				   GWEN_IO_LAYER *ioBase,
+				   uint32_t mark){
   GWEN_IPCNODE *n;
-  GWEN_NETLAYER *nl;
+  GWEN_IO_LAYER *io;
+  int rv;
 
   n=GWEN_IpcNode_new();
 
-  nl=GWEN_NetLayerPackets_new(nlBase);
-  GWEN_Net_AddConnectionToPool(nl);
+  io=GWEN_Io_LayerPackets_new(ioBase);
+  assert(io);
+  rv=GWEN_Io_Manager_RegisterLayer(io);
+  if (rv<0) {
+    DBG_INFO(GWEN_LOGDOMAIN, "Could not register io layer (%d)", rv);
+    GWEN_Io_Layer_free(io);
+    return 0;
+  }
 
-  n->netLayer=nl;
+  n->ioLayer=io;
   n->mark=mark;
   n->isServer=0;
   GWEN_IpcNode_List_Add(n, mgr->nodes);
@@ -510,8 +527,7 @@ void GWEN_IpcManager__RemoveNodeRequestMessages(GWEN_IPCMANAGER *mgr,
 
 
 /* -------------------------------------------------------------- FUNCTION */
-int GWEN_IpcManager_RemoveClient(GWEN_IPCMANAGER *mgr,
-				 GWEN_TYPE_UINT32 nid) {
+int GWEN_IpcManager_RemoveClient(GWEN_IPCMANAGER *mgr, uint32_t nid) {
   GWEN_IPCNODE *n;
 
   DBG_DEBUG(GWEN_LOGDOMAIN, "Removing client %08x", nid);
@@ -538,8 +554,8 @@ int GWEN_IpcManager_RemoveClient(GWEN_IPCMANAGER *mgr,
                                              "newOutRequest");
   /* remove node */
   DBG_NOTICE(GWEN_LOGDOMAIN, "Disconnecting netLayer");
-  GWEN_NetLayer_Disconnect(n->netLayer);
-  GWEN_Net_DelConnectionFromPool(n->netLayer);
+  GWEN_Io_Layer_DisconnectRecursively(n->ioLayer, NULL, GWEN_IO_REQUEST_FLAGS_FORCE, 0, 2000);
+  GWEN_Io_Manager_UnregisterLayer(n->ioLayer);
   DBG_NOTICE(GWEN_LOGDOMAIN, "Removing client %08x", n->id);
   GWEN_IpcNode_List_Del(n);
   GWEN_IpcNode_free(n);
@@ -551,7 +567,7 @@ int GWEN_IpcManager_RemoveClient(GWEN_IPCMANAGER *mgr,
 
 /* -------------------------------------------------------------- FUNCTION */
 GWEN_IPC__REQUEST *GWEN_IpcManager__FindRequest(GWEN_IPCMANAGER *mgr,
-						GWEN_TYPE_UINT32 rid,
+						uint32_t rid,
 						GWEN_IPC__REQUEST *r) {
   assert(mgr);
   assert(r);
@@ -567,12 +583,14 @@ GWEN_IPC__REQUEST *GWEN_IpcManager__FindRequest(GWEN_IPCMANAGER *mgr,
 
 
 /* -------------------------------------------------------------- FUNCTION */
-GWEN_TYPE_UINT32 GWEN_IpcManager_SendRequest(GWEN_IPCMANAGER *mgr,
-                                             GWEN_TYPE_UINT32 nid,
-                                             GWEN_DB_NODE *req){
+int GWEN_IpcManager_SendRequest(GWEN_IPCMANAGER *mgr,
+				uint32_t nid,
+				GWEN_DB_NODE *req,
+				uint32_t *pReqId){
   GWEN_IPCNODE *n;
   GWEN_IPC__REQUEST *r;
   GWEN_IPCMSG *m;
+  int rv;
 
   n=GWEN_IpcNode_List_First(mgr->nodes);
   while(n) {
@@ -582,73 +600,26 @@ GWEN_TYPE_UINT32 GWEN_IpcManager_SendRequest(GWEN_IPCMANAGER *mgr,
   } /* while */
   if (!n) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Node %08x not found", nid);
-    return 0;
+    return GWEN_ERROR_NOT_FOUND;
   }
 
   m=GWEN_IpcMsg_new(n);
   m->db=req;
   m->id=++(n->nextMsgId);
 
-  if (GWEN_IpcManager__SendMsg(mgr, m)) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Could not send request");
+  rv=GWEN_IpcManager__SendMsg(mgr, m);
+  if (rv) {
+    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     GWEN_IpcMsg_free(m);
-    return 0;
+    return rv;
   }
 
   r=GWEN_Ipc__Request_new();
   r->id=++gwen_ipc__lastid;
   GWEN_Ipc__Request_AddRequestMsg(r, m);
   GWEN_Ipc__Request_List_Add(r, mgr->outRequests);
-  return r->id;
-}
+  *pReqId=r->id;
 
-
-
-/* -------------------------------------------------------------- FUNCTION */
-GWEN_TYPE_UINT32 GWEN_IpcManager_SendMultiRequest(GWEN_IPCMANAGER *mgr,
-                                                  GWEN_TYPE_UINT32 mark,
-                                                  GWEN_DB_NODE *req){
-  GWEN_IPCNODE *n;
-  GWEN_IPC__REQUEST *r;
-
-  r=0;
-  n=GWEN_IpcNode_List_First(mgr->nodes);
-  while(n) {
-    if (mark==0 || mark==n->mark) {
-      GWEN_NETLAYER_STATUS st;
-
-      st=GWEN_NetLayer_GetStatus(n->netLayer);
-      if (st!=GWEN_NetLayerStatus_Listening &&
-	  st!=GWEN_NetLayerStatus_Disabled) {
-	GWEN_IPCMSG *m;
-
-        m=GWEN_IpcMsg_new(n);
-        m->db=GWEN_DB_Group_dup(req);
-        m->id=--(n->nextMsgId);
-
-        if (GWEN_IpcManager__SendMsg(mgr, m)) {
-	  DBG_ERROR(GWEN_LOGDOMAIN,
-		    "Could not send request to node %08x",
-		    n->id);
-          GWEN_IpcMsg_free(m);
-        }
-        else {
-          if (r==0) {
-            r=GWEN_Ipc__Request_new();
-	    r->id=++gwen_ipc__lastid;
-            GWEN_Ipc__Request_List_Add(r, mgr->outRequests);
-          }
-          GWEN_Ipc__Request_AddRequestMsg(r, m);
-        }
-      }
-    } /* if mark matches */
-    n=GWEN_IpcNode_List_Next(n);
-  } /* while */
-
-  if (r) {
-    return r->id;
-  }
-  DBG_ERROR(GWEN_LOGDOMAIN, "Could not send any request");
   return 0;
 }
 
@@ -656,11 +627,12 @@ GWEN_TYPE_UINT32 GWEN_IpcManager_SendMultiRequest(GWEN_IPCMANAGER *mgr,
 
 /* -------------------------------------------------------------- FUNCTION */
 int GWEN_IpcManager_SendResponse(GWEN_IPCMANAGER *mgr,
-                                 GWEN_TYPE_UINT32 rid,
+                                 uint32_t rid,
                                  GWEN_DB_NODE *rsp){
   GWEN_IPC__REQUEST *r;
   GWEN_IPCMSG *m;
   GWEN_IPCMSG *om;
+  int rv;
 
   r=GWEN_Ipc__Request_List_First(mgr->oldInRequests);
   while(r) {
@@ -670,7 +642,7 @@ int GWEN_IpcManager_SendResponse(GWEN_IPCMANAGER *mgr,
   } /* while */
   if (!r) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Request %08x not found", rid);
-    return -1;
+    return GWEN_ERROR_NOT_FOUND;
   }
 
   om=GWEN_IpcMsg_List_First(r->requestMsgs);
@@ -684,10 +656,11 @@ int GWEN_IpcManager_SendResponse(GWEN_IPCMANAGER *mgr,
   DBG_DEBUG(GWEN_LOGDOMAIN, "Sending response %08x for request %08x",
 	    m->id, m->refId);
 
-  if (GWEN_IpcManager__SendMsg(mgr, m)) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Could not send response");
+  rv=GWEN_IpcManager__SendMsg(mgr, m);
+  if (rv) {
+    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
     GWEN_IpcMsg_free(m);
-    return -1;
+    return rv;
   }
 
   GWEN_Ipc__Request_AddResponseMsg(r, m);
@@ -698,7 +671,7 @@ int GWEN_IpcManager_SendResponse(GWEN_IPCMANAGER *mgr,
 
 /* -------------------------------------------------------------- FUNCTION */
 int GWEN_IpcManager_RemoveRequest(GWEN_IPCMANAGER *mgr,
-                                  GWEN_TYPE_UINT32 rid,
+                                  uint32_t rid,
                                   int inOrOut){
   GWEN_IPC__REQUEST *r;
 
@@ -724,8 +697,8 @@ int GWEN_IpcManager_RemoveRequest(GWEN_IPCMANAGER *mgr,
 
 
 /* -------------------------------------------------------------- FUNCTION */
-GWEN_TYPE_UINT32 GWEN_IpcManager_GetNextInRequest(GWEN_IPCMANAGER *mgr,
-                                                  GWEN_TYPE_UINT32 mark){
+uint32_t GWEN_IpcManager_GetNextInRequest(GWEN_IPCMANAGER *mgr,
+                                                  uint32_t mark){
   GWEN_IPC__REQUEST *r;
 
   r=GWEN_Ipc__Request_List_First(mgr->newInRequests);
@@ -755,7 +728,7 @@ GWEN_TYPE_UINT32 GWEN_IpcManager_GetNextInRequest(GWEN_IPCMANAGER *mgr,
 
 /* -------------------------------------------------------------- FUNCTION */
 GWEN_DB_NODE *GWEN_IpcManager_GetInRequestData(GWEN_IPCMANAGER *mgr,
-                                               GWEN_TYPE_UINT32 rid){
+                                               uint32_t rid){
   GWEN_IPC__REQUEST *r;
   GWEN_IPCMSG *om;
 
@@ -779,8 +752,7 @@ GWEN_DB_NODE *GWEN_IpcManager_GetInRequestData(GWEN_IPCMANAGER *mgr,
 
 
 /* -------------------------------------------------------------- FUNCTION */
-GWEN_NETLAYER *GWEN_IpcManager_GetNetLayer(GWEN_IPCMANAGER *mgr,
-					   GWEN_TYPE_UINT32 nid){
+GWEN_IO_LAYER *GWEN_IpcManager_GetIoLayer(GWEN_IPCMANAGER *mgr, uint32_t nid){
   GWEN_IPCNODE *n;
 
   n=GWEN_IpcNode_List_First(mgr->nodes);
@@ -794,20 +766,19 @@ GWEN_NETLAYER *GWEN_IpcManager_GetNetLayer(GWEN_IPCMANAGER *mgr,
     return 0;
   }
 
-  return n->netLayer;
+  return n->ioLayer;
 }
 
 
 
 /* -------------------------------------------------------------- FUNCTION */
-GWEN_TYPE_UINT32
-GWEN_IpcManager_GetClientForNetLayer(const GWEN_IPCMANAGER *mgr,
-				     const GWEN_NETLAYER *nl) {
+uint32_t GWEN_IpcManager_GetClientForNetLayer(const GWEN_IPCMANAGER *mgr,
+					      const GWEN_IO_LAYER *io) {
   GWEN_IPCNODE *n;
 
   n=GWEN_IpcNode_List_First(mgr->nodes);
   while(n) {
-    if (n->netLayer==nl)
+    if (n->ioLayer==io)
       break;
     n=GWEN_IpcNode_List_Next(n);
   } /* while */
@@ -822,7 +793,7 @@ GWEN_IpcManager_GetClientForNetLayer(const GWEN_IPCMANAGER *mgr,
 
 /* -------------------------------------------------------------- FUNCTION */
 GWEN_DB_NODE *GWEN_IpcManager_PeekResponseData(GWEN_IPCMANAGER *mgr,
-                                               GWEN_TYPE_UINT32 rid){
+                                               uint32_t rid){
   GWEN_IPC__REQUEST *r;
   GWEN_IPCMSG *m;
   GWEN_DB_NODE *db;
@@ -853,7 +824,7 @@ GWEN_DB_NODE *GWEN_IpcManager_PeekResponseData(GWEN_IPCMANAGER *mgr,
 
 /* -------------------------------------------------------------- FUNCTION */
 GWEN_DB_NODE *GWEN_IpcManager_GetResponseData(GWEN_IPCMANAGER *mgr,
-                                              GWEN_TYPE_UINT32 rid){
+                                              uint32_t rid){
   GWEN_IPC__REQUEST *r;
   GWEN_IPCMSG *m;
   GWEN_DB_NODE *db;
@@ -928,15 +899,15 @@ int GWEN_IpcManager__CheckRequests(GWEN_IPCMANAGER *mgr) {
       assert(m->node);
 
       /* check connection status */
-      assert(m->node->netLayer);
-      if (GWEN_NetLayer_GetStatus(m->node->netLayer)==
-	  GWEN_NetLayerStatus_Disabled) {
+      assert(m->node->ioLayer);
+      if (GWEN_Io_Layer_GetStatus(m->node->ioLayer)==
+	  GWEN_Io_Layer_StatusDisabled) {
 	GWEN_IPCMSG *errm;
 
 	/* connection broken, remove msg */
-        DBG_INFO(GWEN_LOGDOMAIN, "Connection broken");
-        errm=GWEN_IpcManager__MakeErrorResponse(mgr,
-                                                m,
+	DBG_INFO(GWEN_LOGDOMAIN, "Connection broken");
+	errm=GWEN_IpcManager__MakeErrorResponse(mgr,
+						m,
 						GWEN_IPC_ERROR_CONNERR,
                                                 "Connection down");
         GWEN_IpcMsg_List_Add(errm, r->responseMsgs);
@@ -992,7 +963,7 @@ int GWEN_IpcManager_Work(GWEN_IPCMANAGER *mgr) {
 
 
 /* -------------------------------------------------------------- FUNCTION */
-int GWEN_IpcManager_Disconnect(GWEN_IPCMANAGER *mgr, GWEN_TYPE_UINT32 nid){
+int GWEN_IpcManager_Disconnect(GWEN_IPCMANAGER *mgr, uint32_t nid){
   GWEN_IPCNODE *n;
   int rv;
 
@@ -1018,7 +989,7 @@ int GWEN_IpcManager_Disconnect(GWEN_IPCMANAGER *mgr, GWEN_TYPE_UINT32 nid){
   GWEN_IpcManager__RemoveNodeRequestMessages(mgr, n, mgr->oldInRequests,
                                              "newOutRequest");
 
-  rv=GWEN_NetLayer_Disconnect(n->netLayer);
+  rv=GWEN_Io_Layer_DisconnectRecursively(n->ioLayer, NULL, 0, 0, 2000);
   return rv;
 }
 
@@ -1112,33 +1083,31 @@ void GWEN_IpcManager_Dump(GWEN_IPCMANAGER *mgr, FILE *f, int indent){
 int GWEN_IpcManager__SendMsg(GWEN_IPCMANAGER *mgr,
                              GWEN_IPCMSG *m) {
   GWEN_BUFFER *buf;
-  GWEN_BUFFEREDIO *bio;
-  GWEN_ERRORCODE err;
+  int err;
   GWEN_DB_NODE *dbReq;
   GWEN_DB_NODE *dbIpc;
   GWEN_DB_NODE *dbData;
   char numbuf[16];
-  GWEN_NETLAYER_STATUS nst;
+  GWEN_IO_LAYER_STATUS nst;
   int rv;
-  GWEN_NL_PACKET *pk;
 
-  nst=GWEN_NetLayer_GetStatus(m->node->netLayer);
-  if (nst==GWEN_NetLayerStatus_Disabled) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "NetLayer is disabled");
-    return -1;
+  nst=GWEN_Io_Layer_GetStatus(m->node->ioLayer);
+  if (nst==GWEN_Io_Layer_StatusDisabled) {
+    DBG_INFO(GWEN_LOGDOMAIN, "NetLayer is disabled");
+    return GWEN_ERROR_NOT_OPEN;
   }
 
   /* check for connection state, connect if necessary */
-  if (nst==GWEN_NetLayerStatus_Unconnected) {
+  if (nst==GWEN_Io_Layer_StatusUnconnected) {
     if (m->node->isPassiveClient) {
-      DBG_ERROR(GWEN_LOGDOMAIN,
-		"Passive IPC client \"%08x\" is down, "
-		"not sending message", m->node->id);
+      DBG_INFO(GWEN_LOGDOMAIN,
+	       "Passive IPC client \"%08x\" is down, "
+	       "not sending message", m->node->id);
       return -1;
     }
-    rv=GWEN_NetLayer_Connect(m->node->netLayer);
+    rv=GWEN_Io_Layer_ConnectRecursively(m->node->ioLayer, NULL, 0, 0, 10000);
     if (rv<0) {
-      DBG_ERROR(GWEN_LOGDOMAIN, "Could not connect");
+      DBG_INFO(GWEN_LOGDOMAIN, "Could not connect (%d)", rv);
       return rv;
     }
   }
@@ -1161,42 +1130,39 @@ int GWEN_IpcManager__SendMsg(GWEN_IPCMANAGER *mgr,
   GWEN_DB_AddGroupChildren(dbData, m->db);
 
   buf=GWEN_Buffer_new(0, 512, 0, 1);
-  bio=GWEN_BufferedIO_Buffer2_new(buf, 0); /* don't relinquish buffer */
-
   /* encode db */
-  GWEN_BufferedIO_SetWriteBuffer(bio, 0, 128);
-  if (GWEN_DB_WriteToStream(dbReq, bio, GWEN_DB_FLAGS_COMPACT)) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Could not encode db");
-    GWEN_BufferedIO_Abandon(bio);
-    GWEN_BufferedIO_free(bio);
+  err=GWEN_DB_WriteToBuffer(dbReq, buf, GWEN_DB_FLAGS_COMPACT, 0, 2000);
+  if (err) {
+    DBG_INFO(GWEN_LOGDOMAIN, "Could not encode db (%d)", err);
     GWEN_Buffer_free(buf);
     GWEN_DB_Group_free(dbReq);
-    return -1;
+    return err;
   }
   GWEN_DB_Group_free(dbReq);
 
-  err=GWEN_BufferedIO_Close(bio);
-  if (!GWEN_Error_IsOk(err)) {
-    DBG_ERROR_ERR(GWEN_LOGDOMAIN, err);
-    GWEN_BufferedIO_free(bio);
-    GWEN_Buffer_free(buf);
-    return -1;
-  }
-  GWEN_BufferedIO_free(bio);
-
-  /* create packet */
-  pk=GWEN_NL_Packet_new();
-  GWEN_Buffer_Rewind(buf);
-  GWEN_NL_Packet_SetBuffer(pk, buf);
-
-  /* send message */
-  rv=GWEN_NetLayerPackets_SendPacket(m->node->netLayer, pk);
+  rv=GWEN_Buffer_Relinquish(buf);
   if (rv<0) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Could not send package");
-    GWEN_NL_Packet_free(pk);
+    DBG_ERROR(GWEN_LOGDOMAIN, "Internal error, buffer does not relinquish data (%d)", rv);
+    GWEN_Buffer_free(buf);
+    return GWEN_ERROR_INTERNAL;
+  }
+
+  /* send packet */
+  rv=GWEN_Io_Layer_WriteBytes(m->node->ioLayer,
+			      (const uint8_t*)GWEN_Buffer_GetStart(buf),
+			      GWEN_Buffer_GetUsedBytes(buf),
+			      GWEN_IO_REQUEST_FLAGS_PACKETBEGIN |
+			      GWEN_IO_REQUEST_FLAGS_PACKETEND |
+			      GWEN_IO_REQUEST_FLAGS_TAKEOVER |
+			      GWEN_IO_REQUEST_FLAGS_FLUSH,
+			      0, 10000);
+  if (rv<0) {
+    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+    GWEN_Buffer_free(buf);
     return rv;
   }
-  GWEN_NL_Packet_free(pk);
+
+  GWEN_Buffer_free(buf);
 
   DBG_DEBUG(GWEN_LOGDOMAIN, "Message is on its way");
   m->sendTime=time(0);
@@ -1209,45 +1175,42 @@ int GWEN_IpcManager__SendMsg(GWEN_IPCMANAGER *mgr,
 /* -------------------------------------------------------------- FUNCTION */
 int GWEN_IpcManager__HandlePacket(GWEN_IPCMANAGER *mgr,
 				  GWEN_IPCNODE *n,
-				  GWEN_NL_PACKET *pk) {
+				  GWEN_IO_REQUEST *pk) {
   GWEN_DB_NODE *dbReq;
   GWEN_DB_NODE *dbIpc;
-  GWEN_TYPE_UINT32 msgId;
-  GWEN_TYPE_UINT32 refId;
-  GWEN_BUFFER *buf;
-  GWEN_BUFFEREDIO *bio;
+  uint32_t msgId;
+  uint32_t refId;
+  const char *pBuffer;
+  uint32_t lBuffer;
   int rv;
 
   /* read and decode message */
-  buf=GWEN_NL_Packet_GetBuffer(pk);
-  assert(buf);
+  pBuffer=(const char*)GWEN_Io_Request_GetBufferPtr(pk);
+  lBuffer=GWEN_Io_Request_GetBufferPos(pk);
+
   DBG_DEBUG(GWEN_LOGDOMAIN, "Got an incoming message");
   if (GWEN_Logger_GetLevel(0)>=GWEN_LoggerLevel_Debug)
-    GWEN_Buffer_Dump(buf, stderr, 2);
-  GWEN_Buffer_Rewind(buf);
-  bio=GWEN_BufferedIO_Buffer2_new(buf, 0); /* don't tak over */
-  GWEN_BufferedIO_SetReadBuffer(bio, 0, 128);
+    GWEN_Text_DumpString(pBuffer, lBuffer, stderr, 2);
   dbReq=GWEN_DB_Group_new("request");
-  rv=GWEN_DB_ReadFromStream(dbReq, bio,
+
+  rv=GWEN_DB_ReadFromString(dbReq, pBuffer, lBuffer,
 			    GWEN_DB_FLAGS_DEFAULT |
-			    GWEN_DB_FLAGS_STOP_ON_EMPTY_LINE);
+			    GWEN_DB_FLAGS_UNTIL_EMPTY_LINE,
+			    0, 2000);
   if (rv) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Invalid incoming request");
-    GWEN_Buffer_Dump(buf, stderr, 2);
-    GWEN_BufferedIO_Abandon(bio);
+    DBG_ERROR(GWEN_LOGDOMAIN, "Bad incoming request (%d)", rv);
+    GWEN_Text_DumpString(pBuffer, lBuffer, stderr, 2);
+    GWEN_DB_Dump(dbReq, stderr, 2);
     GWEN_DB_Group_free(dbReq);
-    GWEN_BufferedIO_free(bio);
     return rv;
   }
-  GWEN_BufferedIO_Close(bio);
-  GWEN_BufferedIO_free(bio);
 
   /* parse decoded message */
   dbIpc=GWEN_DB_GetGroup(dbReq,
 			 GWEN_PATH_FLAGS_NAMEMUSTEXIST,
 			 "ipc");
   if (dbIpc==0) {
-    DBG_ERROR(GWEN_LOGDOMAIN, "Invalid incoming request");
+    DBG_ERROR(GWEN_LOGDOMAIN, "Invalid incoming request (no IPC group)");
     GWEN_DB_Dump(dbReq, stderr, 2);
     GWEN_DB_Group_free(dbReq);
     return -1;
@@ -1329,76 +1292,103 @@ int GWEN_IpcManager__Work(GWEN_IPCMANAGER *mgr) {
   n=GWEN_IpcNode_List_First(mgr->nodes);
   while(n) {
     GWEN_IPCNODE *next;
-#if 0
-    GWEN_NETLAYER_STATUS st;
-#endif
+    GWEN_IO_LAYER_STATUS st;
 
     next=GWEN_IpcNode_List_Next(n);
     DBG_DEBUG(GWEN_LOGDOMAIN, "Checking node");
 
-#if 0
-    st=GWEN_NetLayer_GetStatus(n->netLayer);
-    if (st==GWEN_NetLayerStatus_Disabled) {
-      DBG_INFO(GWEN_LOGDOMAIN,
-	       "NetLayer for passive IPC client \"%0x8\" "
-	       "is disabled, removing it", n->id);
-      GWEN_IpcManager_RemoveClient(mgr, n->id);
-      return 0;
-    }
-
-    if (st==GWEN_NetLayerStatus_Disconnected) {
-      if (n->isPassiveClient) {
-	if (!GWEN_NetLayerPackets_HasNextPacket(n->netLayer)) {
-	  DBG_INFO(GWEN_LOGDOMAIN,
-		   "NetLayer for passive IPC client \"%0x8\" "
-		   "is disconnected, removing it", n->id);
-	  GWEN_IpcManager_RemoveClient(mgr, n->id);
-	  return 0;
+    st=GWEN_Io_Layer_GetStatus(n->ioLayer);
+    if (st==GWEN_Io_Layer_StatusDisabled ||
+	st==GWEN_Io_Layer_StatusDisconnected) {
+      if (!GWEN_Io_LayerPackets_HasReadRequests(n->ioLayer)) {
+	if (!(n->flags & GWEN_IPCNODE_FLAGS_MGR_INFORMED)) {
+	  n->flags|=GWEN_IPCNODE_FLAGS_MGR_INFORMED;
+	  GWEN_Io_Layer_DisconnectRecursively(n->ioLayer, NULL, GWEN_IO_REQUEST_FLAGS_FORCE, 0, 5000);
+	  if (mgr->clientDownFn) {
+	    GWEN_IpcNode_Attach(n);
+            DBG_DEBUG(GWEN_LOGDOMAIN, "Notifying server...");
+	    mgr->clientDownFn(mgr, n->id, n->ioLayer, mgr->user_data);
+	    if (n->usage==1) {
+	      DBG_DEBUG(GWEN_LOGDOMAIN, "Will definately free node");
+	      GWEN_IpcNode_free(n);
+	      n=next;
+              if (n)
+		next=GWEN_IpcNode_List_Next(n);
+	      else
+                next=NULL;
+	    }
+            else
+	      GWEN_IpcNode_free(n);
+	  }
 	}
       }
     }
-#endif
 
-    if (n->isServer) {
-      GWEN_NETLAYER *nl;
-
-      DBG_DEBUG(GWEN_LOGDOMAIN, "Node is a server");
-      /* collect connections */
-      nl=GWEN_NetLayer_GetIncomingLayer(n->netLayer);
-      if (nl) {
-        GWEN_IPCNODE *newnode;
-
-        DBG_INFO(GWEN_LOGDOMAIN, "Got an incoming connection");
-	newnode=GWEN_IpcNode_new();
-	newnode->netLayer=nl;
-	newnode->mark=n->mark;
-	newnode->isPassiveClient=1;
-	GWEN_IpcNode_List_Add(newnode, mgr->nodes);
-	GWEN_Net_AddConnectionToPool(nl);
-        done++;
-      }
+    if (n) {
+      if (n->isServer) {
+	GWEN_IO_LAYER *newLayer;
+  
+	DBG_DEBUG(GWEN_LOGDOMAIN, "Node is a server");
+	/* collect connections */
+	newLayer=GWEN_Io_Layer_GetNextIncomingLayer(n->ioLayer);
+	if (newLayer) {
+	  int rv;
+  
+	  done++;
+	  DBG_INFO(GWEN_LOGDOMAIN, "Got an incoming connection");
+	  rv=GWEN_Io_Manager_RegisterLayer(newLayer);
+	  if (rv<0) {
+	    DBG_INFO(GWEN_LOGDOMAIN, "Could not register io layer (%d)", rv);
+	    GWEN_Io_Layer_free(newLayer);
+	  }
+	  else {
+	    /* make sure all layers are connected */
+	    rv=GWEN_Io_Layer_ConnectRecursively(newLayer, NULL, 0, 0, 10000);
+	    if (rv) {
+	      rv=GWEN_Io_Layer_DisconnectRecursively(newLayer, NULL,
+						     GWEN_IO_REQUEST_FLAGS_FORCE,
+						     0, 2000);
+	      DBG_INFO(GWEN_LOGDOMAIN, "Could not connect io layer (%d)", rv);
+	      GWEN_Io_Layer_free(newLayer);
+	    }
+	    else {
+	      GWEN_IPCNODE *newnode;
+  
+	      newnode=GWEN_IpcNode_new();
+	      newnode->ioLayer=newLayer;
+	      newnode->mark=n->mark;
+	      newnode->isPassiveClient=1;
+	      GWEN_IpcNode_List_Add(newnode, mgr->nodes);
+	    }
+	  }
+	}
+	else {
+	  DBG_DEBUG(GWEN_LOGDOMAIN, "No incoming connection");
+	}
+      } /* if isServer */
       else {
-        DBG_DEBUG(GWEN_LOGDOMAIN, "No incoming connection");
-      }
-    } /* if isServer */
-    else {
-      GWEN_NL_PACKET *pk;
-      int rv;
-
-      DBG_DEBUG(GWEN_LOGDOMAIN, "Node is NOT a server");
-      pk=GWEN_NetLayerPackets_GetNextPacket(n->netLayer);
-      if (pk) {
-        rv=GWEN_IpcManager__HandlePacket(mgr, n, pk);
-	GWEN_NL_Packet_free(pk);
+	GWEN_IO_REQUEST *pk;
+	int rv;
+  
+	DBG_DEBUG(GWEN_LOGDOMAIN, "Node is NOT a server");
+	rv=GWEN_Io_LayerPackets_GetReadRequest(n->ioLayer, &pk, 0, GWEN_TIMEOUT_NONE);
 	if (rv) {
-          DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+	  if (rv!=GWEN_ERROR_TIMEOUT && rv!=GWEN_ERROR_TRY_AGAIN) {
+	    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+	    done++;
+	  }
 	}
-	done++;
-      }
-      else {
-	DBG_DEBUG(GWEN_LOGDOMAIN, "No message");
-      }
-    } /* if client */
+	else {
+	  rv=GWEN_IpcManager__HandlePacket(mgr, n, pk);
+	  GWEN_Io_Request_free(pk);
+	  if (rv) {
+	    DBG_INFO(GWEN_LOGDOMAIN, "here (%d)", rv);
+	  }
+	  done++;
+	}
+      } /* if client */
+    } /* if n */
+
     n=next;
   } /* while */
 
@@ -1409,6 +1399,16 @@ int GWEN_IpcManager__Work(GWEN_IPCMANAGER *mgr) {
 
 
 
+void GWEN_IpcManager_SetClientDownFn(GWEN_IPCMANAGER *mgr,
+				     GWEN_IPCMANAGER_CLIENTDOWN_FN f,
+				     void *user_data) {
+  assert(mgr);
+  mgr->clientDownFn=f;
+  mgr->user_data=user_data;
+}
+
+
+
 
 
 
