@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: directory.h 1084 2006-07-20 12:32:56Z christian $
+    cvs         : $Id: directory.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Tue Dec 03 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -38,7 +38,7 @@
 extern "C" {
 #endif
 
-typedef struct GWEN_DIRECTORYDATASTRUCT GWEN_DIRECTORYDATA;
+typedef struct GWEN_DIRECTORY GWEN_DIRECTORY;
 
 #ifdef __cplusplus
 }
@@ -74,12 +74,12 @@ extern "C" {
 /**
  * Constructor.
  */
-GWENHYWFAR_API GWEN_DIRECTORYDATA *GWEN_Directory_new();
+GWENHYWFAR_API GWEN_DIRECTORY *GWEN_Directory_new();
 
 /**
  * Destructor
  */
-GWENHYWFAR_API void GWEN_Directory_free(GWEN_DIRECTORYDATA *d);
+GWENHYWFAR_API void GWEN_Directory_free(GWEN_DIRECTORY *d);
 
 /**
  * Opens a directory. This allows calling "Directory_Read" to succeed.
@@ -90,7 +90,7 @@ GWENHYWFAR_API void GWEN_Directory_free(GWEN_DIRECTORYDATA *d);
  * @param n path and name of the directory to open
  */
 GWENHYWFAR_API
-  int GWEN_Directory_Open(GWEN_DIRECTORYDATA *d, const char *n);
+  int GWEN_Directory_Open(GWEN_DIRECTORY *d, const char *n);
 
 /**
  * Closes a previously opened directory.
@@ -99,7 +99,7 @@ GWENHYWFAR_API
  * @param d pointer to a directory data structure. This should be created
  * by calling @ref GWEN_Directory_new().
  */
-GWENHYWFAR_API int GWEN_Directory_Close(GWEN_DIRECTORYDATA *d);
+GWENHYWFAR_API int GWEN_Directory_Close(GWEN_DIRECTORY *d);
 
 /**
  * Reads the next entry from a directory and stores the name of that
@@ -112,7 +112,7 @@ GWENHYWFAR_API int GWEN_Directory_Close(GWEN_DIRECTORYDATA *d);
  * @param buffer pointer to a buffer to receive the name
  * @param len size of the buffer
  */
-GWENHYWFAR_API int GWEN_Directory_Read(GWEN_DIRECTORYDATA *d,
+GWENHYWFAR_API int GWEN_Directory_Read(GWEN_DIRECTORY *d,
                                        char *buffer,
                                        unsigned int len);
 
@@ -124,16 +124,49 @@ GWENHYWFAR_API int GWEN_Directory_Read(GWEN_DIRECTORYDATA *d,
  * @param d pointer to a directory data structure. This should be created
  * by calling @ref GWEN_Directory_new().
  */
-GWENHYWFAR_API int GWEN_Directory_Rewind(GWEN_DIRECTORYDATA *d);
+GWENHYWFAR_API int GWEN_Directory_Rewind(GWEN_DIRECTORY *d);
 
 
 /**
- * Get the current users home directory and copy it into the given buffer.
+ * Gets the current user's home directory and copies it into the
+ * given buffer.
+ *
+ * On Unix, this looks up the passwd entry of the current user,
+ * similar to glib's g_get_home_dir(). Watch out: The environment
+ * variable "HOME" is *not* used, not even as a fallback if there
+ * is no passwd entry (different from g_get_home_dir()).
+ *
+ * On Windows, this looks up the environment variable "HOME", then
+ * "USERPROFILE", then the Windows system directory. This
+ * behaviour is identical to glib's g_get_home_dir(). Watch out:
+ * In the normal non-mingw/msys environment, only "USERPROFILE" is
+ * set, e.g. to "c:\Documents\Yourusername". But if this function
+ * is called from within msys, then msys itself has set "HOME" to
+ * a different value, e.g. to "c:\msys\1.0\home\yourusername". In
+ * effect, your program will see a different home directory when
+ * run from within msys compared to without msys. This is weird,
+ * but it is identical to the glib behaviour and hence we leave it
+ * at that.
+ *
  * @return 0 if ok, !=0 on error
  */
 GWENHYWFAR_API
 int GWEN_Directory_GetHomeDirectory(char *buffer, unsigned int size);
 
+/**
+ * Gets the directory to use for temporary files and copies it
+ * into the given buffer.
+ *
+ * This is found from inspecting the environment variables TMPDIR,
+ * TMP, and TEMP in that order. If none of those are defined,
+ * "/tmp" is returned on UNIX and "C:\" on Windows. This is
+ * similar to glib's g_get_tmp_dir().
+ *
+ * @return 0 if ok, !=0 on error
+ */
+GWENHYWFAR_API
+int GWEN_Directory_GetTmpDirectory(char *buffer, unsigned int size);
+
 /**
  * Gets a file path. It uses @ref MOD_PATH to either create or check for
  * the existence of a given path.
