@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: directory_all.c 1067 2006-05-22 15:25:23Z christian $
+    cvs         : $Id: directory_all.c 1394 2007-12-01 17:31:42Z martin $
     begin       : Sun Nov 23 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -252,8 +252,8 @@ int GWEN_Directory_OsifyPath(const char *path, GWEN_BUFFER *pbuf,
   if (transformDriveElement) {
     if (*p=='/')
       if (isalpha(p[1]))
-        if (p[2]=='/') {
-          GWEN_Buffer_AppendByte(pbuf, p[0]);
+	if (p[2]=='/' || p[2]==0) {
+	  GWEN_Buffer_AppendByte(pbuf, p[0]);
           GWEN_Buffer_AppendByte(pbuf, ':');
           p+=2;
         }
@@ -295,15 +295,15 @@ int GWEN_Directory_FindFileInPaths(const GWEN_STRINGLIST *paths,
     GWEN_Buffer_AppendString(tbuf, GWEN_StringListEntry_Data(se));
     GWEN_Buffer_AppendString(tbuf, DIRSEP);
     GWEN_Buffer_AppendString(tbuf, filePath);
-    DBG_ERROR(GWEN_LOGDOMAIN, "Trying \"%s\"",
-              GWEN_Buffer_GetStart(tbuf));
+    DBG_DEBUG(GWEN_LOGDOMAIN, "Trying \"%s\"",
+	      GWEN_Buffer_GetStart(tbuf));
     f=fopen(GWEN_Buffer_GetStart(tbuf), "r");
     if (f) {
       fclose(f);
-      DBG_ERROR(GWEN_LOGDOMAIN,
-                "File \"%s\" found in folder \"%s\"",
-                filePath,
-                GWEN_StringListEntry_Data(se));
+      DBG_DEBUG(GWEN_LOGDOMAIN,
+		"File \"%s\" found in folder \"%s\"",
+		filePath,
+		GWEN_StringListEntry_Data(se));
       GWEN_Buffer_AppendBuffer(fbuf, tbuf);
       GWEN_Buffer_free(tbuf);
       return 0;
@@ -313,7 +313,7 @@ int GWEN_Directory_FindFileInPaths(const GWEN_STRINGLIST *paths,
     se=GWEN_StringListEntry_Next(se);
   }
 
-  DBG_ERROR(GWEN_LOGDOMAIN, "File \"%s\" not found", filePath);
+  DBG_INFO(GWEN_LOGDOMAIN, "File \"%s\" not found", filePath);
   return GWEN_ERROR_NOT_FOUND;
 }
 
@@ -333,15 +333,15 @@ int GWEN_Directory_FindPathForFile(const GWEN_STRINGLIST *paths,
     GWEN_Buffer_AppendString(tbuf, GWEN_StringListEntry_Data(se));
     GWEN_Buffer_AppendString(tbuf, DIRSEP);
     GWEN_Buffer_AppendString(tbuf, filePath);
-    DBG_ERROR(GWEN_LOGDOMAIN, "Trying \"%s\"",
-              GWEN_Buffer_GetStart(tbuf));
+    DBG_DEBUG(GWEN_LOGDOMAIN, "Trying \"%s\"",
+	      GWEN_Buffer_GetStart(tbuf));
     f=fopen(GWEN_Buffer_GetStart(tbuf), "r");
     if (f) {
       fclose(f);
-      DBG_ERROR(GWEN_LOGDOMAIN,
-                "File \"%s\" found in folder \"%s\"",
-                filePath,
-                GWEN_StringListEntry_Data(se));
+      DBG_INFO(GWEN_LOGDOMAIN,
+	       "File \"%s\" found in folder \"%s\"",
+	       filePath,
+	       GWEN_StringListEntry_Data(se));
       GWEN_Buffer_AppendString(fbuf, GWEN_StringListEntry_Data(se));
       GWEN_Buffer_free(tbuf);
       return 0;
@@ -351,16 +351,38 @@ int GWEN_Directory_FindPathForFile(const GWEN_STRINGLIST *paths,
     se=GWEN_StringListEntry_Next(se);
   }
 
-  DBG_ERROR(GWEN_LOGDOMAIN, "File \"%s\" not found", filePath);
+  DBG_INFO(GWEN_LOGDOMAIN, "File \"%s\" not found", filePath);
   return GWEN_ERROR_NOT_FOUND;
 }
 
 
 
+int GWEN_Directory_GetTmpDirectory(char *buffer, unsigned int size)
+{
+  const char *tmp_dir;
+  assert(buffer);
+
+  /* Copied from http://svn.gnome.org/viewcvs/glib/trunk/glib/gutils.c */
+  tmp_dir = getenv ("TMPDIR");
+  if (!tmp_dir)
+    tmp_dir = getenv ("TMP");
+  if (!tmp_dir)
+    tmp_dir = getenv ("TEMP");
+
+  if (!tmp_dir)
+    {
+#ifdef OS_WIN32
+      tmp_dir = "C:\\";
+#else  
+      tmp_dir = "/tmp";
+#endif	/* !OS_WIN32 */
+    }
+
+  strncpy (buffer, tmp_dir, size);
+  return 0;
+}
+
+
+
 
 
-
-
-
-
-
