@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: gwentime_p.h 592 2004-11-19 12:26:31Z aquamaniac $
+    cvs         : $Id: gwentime_p.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Wed Mar 24 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -35,18 +35,18 @@
 #define GWEN_TIME_TMPL_MAX_COUNT 8
 
 struct GWEN_TIME {
-  GWEN_TYPE_UINT32 secs;
-  GWEN_TYPE_UINT32 msecs;
+  uint32_t secs;
+  uint32_t msecs;
 };
 
 
 
-GWEN_TYPE_UINT32 GWEN_Time__mktimeUtc(int year,
-                                      int month,
-                                      int day,
-                                      int hour,
-                                      int min,
-                                      int sec);
+uint32_t GWEN_Time__mktimeUtc(int year,
+			      int month,
+			      int day,
+			      int hour,
+			      int min,
+			      int sec);
 
 
 
