@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: inetaddr_l.h 349 2004-05-06 11:02:04Z aquamaniac $
+    cvs         : $Id: inetaddr_l.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Tue Oct 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -39,12 +39,12 @@
 /**
  * Initialize this module.
  */
-GWEN_ERRORCODE GWEN_InetAddr_ModuleInit();
+int GWEN_InetAddr_ModuleInit();
 
 /**
  * De-Initialize this module.
  */
-GWEN_ERRORCODE GWEN_InetAddr_ModuleFini();
+int GWEN_InetAddr_ModuleFini();
 
 
 #endif /* GWEN_INETADDR_L_H */
