@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: inetsocket_l.h 349 2004-05-06 11:02:04Z aquamaniac $
+    cvs         : $Id: inetsocket_l.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Tue Oct 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -38,18 +38,12 @@ extern "C" {
 /**
  * Initializes this module.
  */
-GWEN_ERRORCODE GWEN_Socket_ModuleInit();
+int GWEN_Socket_ModuleInit();
 
 /**
  * Deinitializes this module.
  */
-GWEN_ERRORCODE GWEN_Socket_ModuleFini();
-
-/**
- * @internal
- * This is an internal function, it should not be used by an application.
- */
-GWENHYWFAR_API int GWEN_Socket_GetSocketInt(const GWEN_SOCKET *sp);
+int GWEN_Socket_ModuleFini();
 
 
 #ifdef __cplusplus
