@@ -1,7 +1,7 @@
 /***************************************************************************
   $RCSfile$
                              -------------------
-    cvs         : $Id: libloader.h 462 2004-07-30 10:33:08Z cstim $
+    cvs         : $Id: libloader.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Fri Nov 22 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -57,7 +57,7 @@ extern "C" {
 /*@{*/
 
 
-typedef struct GWEN_LIBLOADERSTRUCT GWEN_LIBLOADER;
+typedef struct GWEN_LIBLOADER GWEN_LIBLOADER;
 
 
 GWENHYWFAR_API GWEN_LIBLOADER *GWEN_LibLoader_new();
@@ -71,18 +71,18 @@ GWENHYWFAR_API GWEN_LIBLOADER *GWEN_LibLoader_new();
 GWENHYWFAR_API void GWEN_LibLoader_free(GWEN_LIBLOADER *h);
 
 GWENHYWFAR_API
-  GWEN_ERRORCODE GWEN_LibLoader_OpenLibrary(GWEN_LIBLOADER *h,
-                                            const char *name);
+  int GWEN_LibLoader_OpenLibrary(GWEN_LIBLOADER *h,
+				 const char *name);
 GWENHYWFAR_API
-  GWEN_ERRORCODE GWEN_LibLoader_OpenLibraryWithPath(GWEN_LIBLOADER *h,
-                                                    const char *path,
-                                                    const char *name);
+  int GWEN_LibLoader_OpenLibraryWithPath(GWEN_LIBLOADER *h,
+					 const char *path,
+					 const char *name);
 
 GWENHYWFAR_API
-  GWEN_ERRORCODE GWEN_LibLoader_CloseLibrary(GWEN_LIBLOADER *h);
+  int GWEN_LibLoader_CloseLibrary(GWEN_LIBLOADER *h);
 GWENHYWFAR_API
-  GWEN_ERRORCODE GWEN_LibLoader_Resolve(GWEN_LIBLOADER *h,
-                                        const char *name, void **p);
+  int GWEN_LibLoader_Resolve(GWEN_LIBLOADER *h,
+			     const char *name, void **p);
 
 /*@}*/
 
