@@ -1,7 +1,7 @@
 /***************************************************************************
   $RCSfile$
                              -------------------
-    cvs         : $Id: libloader_l.h 349 2004-05-06 11:02:04Z aquamaniac $
+    cvs         : $Id: libloader_l.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Fri Nov 22 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -33,8 +33,8 @@
 #include <gwenhywfar/libloader.h>
 
 
-GWEN_ERRORCODE GWEN_LibLoader_ModuleInit();
-GWEN_ERRORCODE GWEN_LibLoader_ModuleFini();
+int GWEN_LibLoader_ModuleInit();
+int GWEN_LibLoader_ModuleFini();
 
 
 #endif /* GWENHYWFAR_LIBLOADER_L_H */
