@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: directory_p.h 92 2003-11-22 19:19:10Z aquamaniac $
+    cvs         : $Id: directory_p.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Tue Dec 03 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -46,7 +46,7 @@
 extern "C" {
 #endif
 
-struct GWEN_DIRECTORYDATASTRUCT {
+struct GWEN_DIRECTORY {
   DIR *handle;
 };
 
