@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: init.c 957 2005-12-23 01:43:18Z aquamaniac $
+    cvs         : $Id: init.c 1393 2007-11-22 18:26:05Z martin $
     begin       : Wed Mar 27 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -42,10 +42,10 @@ static void GWEN_LibFini() __attribute__((destructor));
 
 
 void GWEN_LibInit() {
-  GWEN_ERRORCODE err;
+  int err;
 
   err=GWEN_Init();
-  if (!GWEN_Error_IsOk(err)) {
+  if (err) {
     fprintf(stderr, "Could not initialize Gwenhywfar, aborting\n");
     abort();
   }
@@ -54,12 +54,13 @@ void GWEN_LibInit() {
 
 
 void GWEN_LibFini() {
-  GWEN_ERRORCODE err;
+  int err;
 
   err=GWEN_Fini_Forced();
-  if (!GWEN_Error_IsOk(err)) {
+  if (err) {
     fprintf(stderr, "Could not deinitialize Gwenhywfar\n");
   }
   /* fprintf(stderr, "Gwenhywfar deinitialized.\n"); */
 }
 
+
