@@ -1,7 +1,7 @@
 /***************************************************************************
   $RCSfile$
                              -------------------
-    cvs         : $Id: libloader_p.h 349 2004-05-06 11:02:04Z aquamaniac $
+    cvs         : $Id: libloader_p.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Fri Nov 22 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -35,23 +35,12 @@
 #include <gwenhywfar/error.h>
 
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-
-GWENHYWFAR_API struct GWEN_LIBLOADERSTRUCT {
+struct GWEN_LIBLOADER {
   void *handle;
 };
 
 
-GWEN_ERRORCODE GWEN_LibLoader_LoadLibrary(GWEN_LIBLOADER *h,
-                                          const char *name);
-
-
-#ifdef __cplusplus
-}
-#endif
+int GWEN_LibLoader_LoadLibrary(GWEN_LIBLOADER *h, const char *name);
 
 
 #endif /* GWENHYWFAR_LIBLOADER_P_H */
