@@ -1,7 +1,7 @@
 /***************************************************************************
   $RCSfile$
                              -------------------
-    cvs         : $Id: process.c 957 2005-12-23 01:43:18Z aquamaniac $
+    cvs         : $Id: process.c 1393 2007-11-22 18:26:05Z martin $
     begin       : Sat Dec 27 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -51,13 +51,13 @@
 static GWEN_PROCESS *GWEN_Process_ProcessList=0;
 
 
-GWEN_ERRORCODE GWEN_Process_ModuleInit(){
+int GWEN_Process_ModuleInit(){
   return 0;
 }
 
 
 
-GWEN_ERRORCODE GWEN_Process_ModuleFini(){
+int GWEN_Process_ModuleFini(){
   GWEN_PROCESS *pr, *prnext;
 
   pr=GWEN_Process_ProcessList;
@@ -73,6 +73,7 @@ GWEN_ERRORCODE GWEN_Process_ModuleFini(){
 
 
 
+#if 0
 GWEN_PROCESS *GWEN_Process_FindProcess(pid_t pid){
   GWEN_PROCESS *pr;
 
@@ -126,6 +127,7 @@ void GWEN_Process_SignalHandler(int s) {
   } /* switch */
 
 }
+#endif
 
 
 
@@ -163,10 +165,10 @@ GWEN_PROCESS_STATE GWEN_Process_Start(GWEN_PROCESS *pr,
 				      const char *prg,
 				      const char *args){
   pid_t pid;
-  char buffer[128];
   char *argv[32];
   int argc;
   const char *p, *p2;
+  GWEN_BUFFER *wbuf;
 
   assert(pr);
 
@@ -255,23 +257,27 @@ GWEN_PROCESS_STATE GWEN_Process_Start(GWEN_PROCESS *pr,
   argv[0]=strdup(prg);
   argc++;
   p=args;
+  wbuf=GWEN_Buffer_new(0, 256, 0, 1);
   while(argc<32 && *p) {
     while(*p && isspace((int)*p))
       p++;
     if (!(*p))
       break;
-    p2=GWEN_Text_GetWord(p, " ",
-			 buffer, sizeof(buffer),
-			 GWEN_TEXT_FLAGS_NULL_IS_DELIMITER |
-			 GWEN_TEXT_FLAGS_DEL_QUOTES |
-			 GWEN_TEXT_FLAGS_CHECK_BACKSLASH,
-			 &p);
-    if (!p2)
+    if (GWEN_Text_GetWordToBuffer(p, " ",
+				  wbuf,
+				  GWEN_TEXT_FLAGS_NULL_IS_DELIMITER |
+				  GWEN_TEXT_FLAGS_DEL_QUOTES |
+				  GWEN_TEXT_FLAGS_CHECK_BACKSLASH,
+				  &p))
       break;
 
+    p2=GWEN_Buffer_GetStart(wbuf);
+
     argv[argc]=strdup(p2);
+    GWEN_Buffer_Reset(wbuf);
     argc++;
   } /* while */
+  GWEN_Buffer_free(wbuf);
   argv[argc]=0;
   /* parameters ready, exec */
   execvp(prg, argv);
@@ -414,28 +420,28 @@ int GWEN_Process_Terminate(GWEN_PROCESS *pr){
 
 
 
-GWEN_TYPE_UINT32 GWEN_Process_GetFlags(const GWEN_PROCESS *pr){
+uint32_t GWEN_Process_GetFlags(const GWEN_PROCESS *pr){
   assert(pr);
   return pr->pflags;
 }
 
 
 
-void GWEN_Process_SetFlags(GWEN_PROCESS *pr, GWEN_TYPE_UINT32 f){
+void GWEN_Process_SetFlags(GWEN_PROCESS *pr, uint32_t f){
   assert(pr);
   pr->pflags=f;
 }
 
 
 
-void GWEN_Process_AddFlags(GWEN_PROCESS *pr, GWEN_TYPE_UINT32 f){
+void GWEN_Process_AddFlags(GWEN_PROCESS *pr, uint32_t f){
   assert(pr);
   pr->pflags|=f;
 }
 
 
 
-void GWEN_Process_SubFlags(GWEN_PROCESS *pr, GWEN_TYPE_UINT32 f){
+void GWEN_Process_SubFlags(GWEN_PROCESS *pr, uint32_t f){
   assert(pr);
   pr->pflags&=~f;
 }
