@@ -1,7 +1,7 @@
 /***************************************************************************
   $RCSfile$
                              -------------------
-    cvs         : $Id: process_p.h 601 2004-11-19 22:27:24Z aquamaniac $
+    cvs         : $Id: process_p.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Sat Dec 27 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -47,7 +47,7 @@ struct GWEN_PROCESS {
   int filesStdout[2];
   int filesStderr[2];
   GWEN_PROCESS_STATE state;
-  GWEN_TYPE_UINT32 pflags;
+  uint32_t pflags;
   GWEN_BUFFEREDIO *stdIn;
   GWEN_BUFFEREDIO *stdOut;
   GWEN_BUFFEREDIO *stdErr;
@@ -55,11 +55,13 @@ struct GWEN_PROCESS {
 
 
 
+static
 GWEN_PROCESS_STATE GWEN_Process_GetState(GWEN_PROCESS *pr, int w);
-void GWEN_Process_SignalHandler(int s);
-GWEN_PROCESS *GWEN_Process_FindProcess(pid_t pid);
+
+static
 GWEN_PROCESS_STATE GWEN_Process_MakeState(GWEN_PROCESS *pr, int status);
 
+static
 int GWEN_Process_Redirect(GWEN_PROCESS *pr);
 
 
