@@ -1,7 +1,7 @@
 /***************************************************************************
   $RCSfile$
                              -------------------
-    cvs         : $Id: process.h 523 2004-08-20 20:35:27Z aquamaniac $
+    cvs         : $Id: process.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Sat Dec 27 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -71,17 +71,6 @@ extern "C" {
   } GWEN_PROCESS_STATE;
 
 
-  /**
-   * Initialize this module.
-   */
-  GWENHYWFAR_API GWEN_ERRORCODE GWEN_Process_ModuleInit();
-
-  /**
-   * De-Initialize this module.
-   */
-  GWENHYWFAR_API GWEN_ERRORCODE GWEN_Process_ModuleFini();
-
-
   /**
    * Creates a process representation. This does not start a process, it
    * simply prepares some data for starting a process.
@@ -101,28 +90,28 @@ extern "C" {
    * (see @ref GWEN_PROCESS_FLAGS_REDIR_STDOUT and others)
    */
   GWENHYWFAR_API
-    GWEN_TYPE_UINT32 GWEN_Process_GetFlags(const GWEN_PROCESS *pr);
+    uint32_t GWEN_Process_GetFlags(const GWEN_PROCESS *pr);
 
   /**
    * Sets the process flags to the given value
    * (see @ref GWEN_PROCESS_FLAGS_REDIR_STDOUT and others)
    */
   GWENHYWFAR_API
-    void GWEN_Process_SetFlags(GWEN_PROCESS *pr, GWEN_TYPE_UINT32 f);
+    void GWEN_Process_SetFlags(GWEN_PROCESS *pr, uint32_t f);
 
   /**
    * Adds the given flag to the current process flags
    * (see @ref GWEN_PROCESS_FLAGS_REDIR_STDOUT and others)
    */
   GWENHYWFAR_API
-    void GWEN_Process_AddFlags(GWEN_PROCESS *pr, GWEN_TYPE_UINT32 f);
+    void GWEN_Process_AddFlags(GWEN_PROCESS *pr, uint32_t f);
 
   /**
    * Removes the given flag from the current process flags
    * (see @ref GWEN_PROCESS_FLAGS_REDIR_STDOUT and others)
    */
   GWENHYWFAR_API
-    void GWEN_Process_SubFlags(GWEN_PROCESS *pr, GWEN_TYPE_UINT32 f);
+    void GWEN_Process_SubFlags(GWEN_PROCESS *pr, uint32_t f);
 
   /**
    * Starts the given process.
