@@ -1,7 +1,7 @@
 /***************************************************************************
   $RCSfile$
                              -------------------
-    cvs         : $Id: process_l.h 349 2004-05-06 11:02:04Z aquamaniac $
+    cvs         : $Id: process_l.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Sat Dec 27 2003
     copyright   : (C) 2003 by Martin Preuss
     email       : martin@libchipcard.de
@@ -35,12 +35,12 @@
 /**
  * Initialize this module.
  */
-GWEN_ERRORCODE GWEN_Process_ModuleInit();
+int GWEN_Process_ModuleInit();
 
 /**
  * De-Initialize this module.
  */
-GWEN_ERRORCODE GWEN_Process_ModuleFini();
+int GWEN_Process_ModuleFini();
 
 
 
