@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: gwentime.c 515 2004-08-17 09:29:57Z cstim $
+    cvs         : $Id: gwentime.c 1393 2007-11-22 18:26:05Z martin $
     begin       : Wed Mar 24 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -47,7 +47,7 @@
 int GWEN_Time__GetCurrentTime(GWEN_TIME *ti){
   long sec, msec;
   union {
-    GWEN_TYPE_UINT64 ns100; /* time since 1 Jan 1601 in 100ns units */
+    uint64_t ns100; /* time since 1 Jan 1601 in 100ns units */
     FILETIME ft;
   } current_date;
 
