@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: inetaddr.c 957 2005-12-23 01:43:18Z aquamaniac $
+    cvs         : $Id: inetaddr.c 1393 2007-11-22 18:26:05Z martin $
     begin       : Tue Oct 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -40,97 +40,29 @@
 
 /* #define MEMTRACE */
 
-/* forward declaration */
-const char *GWEN_InetAddr_ErrorString(int c);
-
 #ifdef MEMTRACE
 static int GWEN_INETADDR__Counter=0;
 #endif
 
 
-static int gwen_inetaddr_is_initialized=0;
-static GWEN_ERRORTYPEREGISTRATIONFORM *gwen_inetaddr_errorform=0;
-
-
-GWEN_TYPE_UINT32 GWEN_InetAddr_GetCapabilities(){
+uint32_t GWEN_InetAddr_GetCapabilities(){
   return
     GWEN_INETADDR_CAPS_AF_TCP;
 }
 
 
-GWEN_ERRORCODE GWEN_InetAddr_ModuleInit(){
-  if (!gwen_inetaddr_is_initialized) {
-    GWEN_ERRORCODE err;
-
-    gwen_inetaddr_errorform=GWEN_ErrorType_new();
-    GWEN_ErrorType_SetName(gwen_inetaddr_errorform,
-                           GWEN_INETADDR_ERROR_TYPE);
-    GWEN_ErrorType_SetMsgPtr(gwen_inetaddr_errorform,
-			     GWEN_InetAddr_ErrorString);
-    err=GWEN_Error_RegisterType(gwen_inetaddr_errorform);
-    if (!GWEN_Error_IsOk(err))
-      return err;
-    gwen_inetaddr_is_initialized=1;
-  }
+int GWEN_InetAddr_ModuleInit(){
   return 0;
 }
 
 
 
-GWEN_ERRORCODE GWEN_InetAddr_ModuleFini(){
-  if (gwen_inetaddr_is_initialized) {
-    GWEN_ERRORCODE err;
-
-    err=GWEN_Error_UnregisterType(gwen_inetaddr_errorform);
-    GWEN_ErrorType_free(gwen_inetaddr_errorform);
-    if (!GWEN_Error_IsOk(err))
-      return err;
-    gwen_inetaddr_is_initialized=0;
-  }
+int GWEN_InetAddr_ModuleFini(){
   return 0;
 }
 
 
 
-const char *GWEN_InetAddr_ErrorString(int c) {
-  const char *s;
-
-  switch(c) {
-  case GWEN_INETADDR_ERROR_MEMORY_FULL:
-    s="Memory full";
-    break;
-  case GWEN_INETADDR_ERROR_BAD_ADDRESS:
-    s="Bad address";
-    break;
-  case GWEN_INETADDR_ERROR_BUFFER_OVERFLOW:
-    s="Buffer overflow";
-    break;
-  case GWEN_INETADDR_ERROR_HOST_NOT_FOUND:
-    s="Host not found";
-    break;
-  case GWEN_INETADDR_ERROR_NO_ADDRESS:
-    s="No address";
-    break;
-  case GWEN_INETADDR_ERROR_NO_RECOVERY:
-    s="No recovery";
-    break;
-  case GWEN_INETADDR_ERROR_TRY_AGAIN:
-    s="Try again";
-    break;
-  case GWEN_INETADDR_ERROR_UNKNOWN_DNS_ERROR:
-    s="Unknown DNS error";
-    break;
-  case GWEN_INETADDR_ERROR_BAD_ADDRESS_FAMILY:
-    s="Unknown address family";
-    break;
-  default:
-    s=(const char*)0;
-  } /* switch */
-  return s;
-}
-
-
-
 GWEN_INETADDRESS *GWEN_InetAddr_new(GWEN_AddressFamily af){
   GWEN_INETADDRESS *ia;
 
@@ -201,7 +133,7 @@ void GWEN_InetAddr_free(GWEN_INETADDRESS *ia){
 
 
 
-GWEN_ERRORCODE GWEN_InetAddr_SetAddress(GWEN_INETADDRESS *ia,
+int GWEN_InetAddr_SetAddress(GWEN_INETADDRESS *ia,
 					const char *addr){
   assert(ia);
 
@@ -225,10 +157,7 @@ GWEN_ERRORCODE GWEN_InetAddr_SetAddress(GWEN_INETADDRESS *ia,
       aptr->sin_addr.s_addr=inet_addr(addr);
       if (aptr->sin_addr.s_addr==INADDR_NONE)
         /* bad address, so maybe it rather is a name */
-        return GWEN_Error_new(0,
-                              GWEN_ERROR_SEVERITY_ERR,
-                              GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-                              GWEN_INETADDR_ERROR_BAD_ADDRESS);
+        return GWEN_ERROR_BAD_ADDRESS;
     }
 #endif
 
@@ -237,10 +166,7 @@ GWEN_ERRORCODE GWEN_InetAddr_SetAddress(GWEN_INETADDRESS *ia,
       /* ok, address to be set */
       if (!inet_aton(addr,&aptr->sin_addr))
         /* bad address, so maybe it rather is a name */
-	return GWEN_Error_new(0,
-                              GWEN_ERROR_SEVERITY_ERR,
-                              GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-                              GWEN_INETADDR_ERROR_BAD_ADDRESS);
+	return GWEN_ERROR_BAD_ADDRESS;
     }
 #endif
     break;
@@ -248,17 +174,11 @@ GWEN_ERRORCODE GWEN_InetAddr_SetAddress(GWEN_INETADDRESS *ia,
 
   case GWEN_AddressFamilyUnix: {
     DBG_ERROR(GWEN_LOGDOMAIN, "No unix domain sockets available for this system");
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-                          GWEN_INETADDR_ERROR_BAD_ADDRESS_FAMILY);
+    return GWEN_ERROR_BAD_ADDRESS_FAMILY;
     break;
   }
   default:
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-                          GWEN_INETADDR_ERROR_BAD_ADDRESS_FAMILY);
+    return GWEN_ERROR_BAD_ADDRESS_FAMILY;
   } /* switch */
 
   return 0;
@@ -271,19 +191,19 @@ int GWEN_InetAddr_TranslateHError(int herr) {
 
   switch(herr) {
   case WSAHOST_NOT_FOUND:
-    rv=GWEN_INETADDR_ERROR_HOST_NOT_FOUND;
+    rv=GWEN_ERROR_HOST_NOT_FOUND;
     break;
   case WSANO_ADDRESS:
-    rv=GWEN_INETADDR_ERROR_NO_ADDRESS;
+    rv=GWEN_ERROR_NO_ADDRESS;
     break;
   case WSANO_RECOVERY:
-    rv=GWEN_INETADDR_ERROR_NO_RECOVERY;
+    rv=GWEN_ERROR_NO_RECOVERY;
     break;
   case WSATRY_AGAIN:
-    rv=GWEN_INETADDR_ERROR_TRY_AGAIN;
+    rv=GWEN_ERROR_TRY_AGAIN;
     break;
   default:
-    rv=GWEN_INETADDR_ERROR_UNKNOWN_DNS_ERROR;
+    rv=GWEN_ERROR_UNKNOWN_DNS_ERROR;
     break;
   } /* switch */
   return rv;
@@ -291,7 +211,7 @@ int GWEN_InetAddr_TranslateHError(int herr) {
 
 
 
-GWEN_ERRORCODE GWEN_InetAddr_SetName(GWEN_INETADDRESS *ia, const char *name){
+int GWEN_InetAddr_SetName(GWEN_INETADDRESS *ia, const char *name){
   struct hostent *he;
 
   assert(ia);
@@ -304,10 +224,7 @@ GWEN_ERRORCODE GWEN_InetAddr_SetName(GWEN_INETADDRESS *ia, const char *name){
     /* try to resolve name */
     he=gethostbyname(name);
     if (!he)
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-                            GWEN_InetAddr_TranslateHError(h_errno));
+      return GWEN_InetAddr_TranslateHError(h_errno);
     /* name resolved, store address */
     memcpy(&(aptr->sin_addr),
 	   he->h_addr_list[0],
@@ -317,25 +234,19 @@ GWEN_ERRORCODE GWEN_InetAddr_SetName(GWEN_INETADDRESS *ia, const char *name){
 
   case GWEN_AddressFamilyUnix: {
     DBG_ERROR(GWEN_LOGDOMAIN, "No unix domain sockets available for this system");
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-                          GWEN_INETADDR_ERROR_BAD_ADDRESS_FAMILY);
+    return GWEN_ERROR_BAD_ADDRESS_FAMILY;
     break;
   }
 
   default:
-    return GWEN_Error_new(0,
-		     GWEN_ERROR_SEVERITY_ERR,
-		     GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-		     GWEN_INETADDR_ERROR_BAD_ADDRESS_FAMILY);
+    return GWEN_ERROR_BAD_ADDRESS_FAMILY;
   } /* switch */
   return 0;
 }
 
 
 
-GWEN_ERRORCODE GWEN_InetAddr_GetAddress(const GWEN_INETADDRESS *ia,
+int GWEN_InetAddr_GetAddress(const GWEN_INETADDRESS *ia,
 					char *buffer, unsigned int bsize){
   const char *s;
 
@@ -350,34 +261,25 @@ GWEN_ERRORCODE GWEN_InetAddr_GetAddress(const GWEN_INETADDRESS *ia,
     s=inet_ntoa(aptr->sin_addr);
     assert(s);
     if (strlen(s)+1>bsize)
-      return GWEN_Error_new(0,
-		       GWEN_ERROR_SEVERITY_ERR,
-		       GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-		       GWEN_INETADDR_ERROR_BUFFER_OVERFLOW);
+      return GWEN_ERROR_BUFFER_OVERFLOW;
     strcpy(buffer,s);
     break;
   }
 
   case GWEN_AddressFamilyUnix: {
-    return GWEN_Error_new(0,
-		     GWEN_ERROR_SEVERITY_ERR,
-		     GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-		     GWEN_INETADDR_ERROR_BAD_ADDRESS_FAMILY);
+    return GWEN_ERROR_BAD_ADDRESS_FAMILY;
     break;
   }
 
   default:
-    return GWEN_Error_new(0,
-		     GWEN_ERROR_SEVERITY_ERR,
-		     GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-		     GWEN_INETADDR_ERROR_BAD_ADDRESS_FAMILY);
+    return GWEN_ERROR_BAD_ADDRESS_FAMILY;
   } /* switch */
   return 0;
 }
 
 
 
-GWEN_ERRORCODE GWEN_InetAddr_GetName(const GWEN_INETADDRESS *ia,
+int GWEN_InetAddr_GetName(const GWEN_INETADDRESS *ia,
 				     char *buffer, unsigned int bsize){
   struct hostent *he;
   struct in_addr lia;
@@ -398,36 +300,24 @@ GWEN_ERRORCODE GWEN_InetAddr_GetName(const GWEN_INETADDRESS *ia,
     he=gethostbyaddr((char*)&lia,sizeof(lia),AF_INET);
 #endif
     if (!he)
-      return GWEN_Error_new(0,
-		       GWEN_ERROR_SEVERITY_ERR,
-		       GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-		       GWEN_InetAddr_TranslateHError(h_errno));
+      return GWEN_InetAddr_TranslateHError(h_errno);
 
     /* copy name into given buffer */
     assert(he->h_name);
     if (strlen(he->h_name)+1>bsize)
-      return GWEN_Error_new(0,
-		       GWEN_ERROR_SEVERITY_ERR,
-		       GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-		       GWEN_INETADDR_ERROR_BUFFER_OVERFLOW);
+      return GWEN_ERROR_BUFFER_OVERFLOW;
     /* copy the name into the buffer */
     strcpy(buffer,he->h_name);
     break;
   }
 
   case GWEN_AddressFamilyUnix: {
-    return GWEN_Error_new(0,
-		     GWEN_ERROR_SEVERITY_ERR,
-		     GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-		     GWEN_INETADDR_ERROR_BAD_ADDRESS_FAMILY);
+    return GWEN_ERROR_BAD_ADDRESS_FAMILY;
     break;
   }
 
   default:
-    return GWEN_Error_new(0,
-		     GWEN_ERROR_SEVERITY_ERR,
-		     GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-		     GWEN_INETADDR_ERROR_BAD_ADDRESS_FAMILY);
+    return GWEN_ERROR_BAD_ADDRESS_FAMILY;
 
   } /* switch */
 
@@ -461,7 +351,7 @@ int GWEN_InetAddr_GetPort(const GWEN_INETADDRESS *ia){
 
 
 
-GWEN_ERRORCODE GWEN_InetAddr_SetPort(GWEN_INETADDRESS *ia, int port){
+int GWEN_InetAddr_SetPort(GWEN_INETADDRESS *ia, int port){
   assert(ia);
 
   switch (ia->af) {
@@ -474,10 +364,7 @@ GWEN_ERRORCODE GWEN_InetAddr_SetPort(GWEN_INETADDRESS *ia, int port){
   }
 
   default:
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-                          GWEN_INETADDR_ERROR_BAD_ADDRESS_FAMILY);
+    return GWEN_ERROR_BAD_ADDRESS_FAMILY;
   } /* switch */
   return 0;
 }
