@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: inetsocket.c 1091 2006-10-02 21:37:10Z martin $
+    cvs         : $Id: inetsocket.c 1400 2007-12-18 14:22:30Z martin $
     begin       : Tue Oct 02 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -44,11 +44,12 @@
 #include <sys/time.h>
 
 
-/* forward declaration */
-const char *GWEN_Socket_ErrorString(int c);
+
+GWEN_LIST_FUNCTIONS(GWEN_SOCKET, GWEN_Socket)
+GWEN_LIST2_FUNCTIONS(GWEN_SOCKET, GWEN_Socket)
+
 
 static int gwen_socket_is_initialized=0;
-static GWEN_ERRORTYPEREGISTRATIONFORM *gwen_socket_errorform=0;
 
 
 
@@ -776,42 +777,25 @@ char* h_strerror(int errnum) {
 
 
 
-GWEN_ERRORCODE GWEN_Socket_ModuleInit(){
+int GWEN_Socket_ModuleInit(){
   WORD wVersionRequested;
   WSADATA wsaData;
 
   if (!gwen_socket_is_initialized) {
-    GWEN_ERRORCODE err;
     int rv;
 
-    /* register error type */
-    gwen_socket_errorform=GWEN_ErrorType_new();
-    GWEN_ErrorType_SetName(gwen_socket_errorform,
-                           GWEN_SOCKET_ERROR_TYPE);
-    GWEN_ErrorType_SetMsgPtr(gwen_socket_errorform,
-                             GWEN_Socket_ErrorString);
-    err=GWEN_Error_RegisterType(gwen_socket_errorform);
-    if (!GWEN_Error_IsOk(err))
-      return err;
-
     /* setup WINSOCK (request version 1.1) */
     wVersionRequested=MAKEWORD(1,1);
     rv=WSAStartup(wVersionRequested,&wsaData);
     if (rv) {
       DBG_INFO(GWEN_LOGDOMAIN, "Error on WSAStartup");
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                            rv);
+      return rv;
     }
     /* check if the version returned is that we requested */
     if (LOBYTE(wsaData.wVersion)!=1 ||
         HIBYTE(wsaData.wVersion)!=1) {
       WSACleanup();
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                            GWEN_SOCKET_ERROR_STARTUP);
+      return GWEN_ERROR_STARTUP;
     }
 
     gwen_socket_is_initialized=1;
@@ -821,15 +805,11 @@ GWEN_ERRORCODE GWEN_Socket_ModuleInit(){
 
 
 
-GWEN_ERRORCODE GWEN_Socket_ModuleFini(){
+int GWEN_Socket_ModuleFini(){
   if (gwen_socket_is_initialized) {
-    GWEN_ERRORCODE err;
 
     WSACleanup();
-    err=GWEN_Error_UnregisterType(gwen_socket_errorform);
-    GWEN_ErrorType_free(gwen_socket_errorform);
-    if (!GWEN_Error_IsOk(err))
-      return err;
+
     gwen_socket_is_initialized=0;
   }
   return 0;
@@ -837,7 +817,7 @@ GWEN_ERRORCODE GWEN_Socket_ModuleFini(){
 
 
 
-GWEN_ERRORCODE GWEN_SocketSet_Clear(GWEN_SOCKETSET *ssp){
+int GWEN_SocketSet_Clear(GWEN_SOCKETSET *ssp){
   assert(ssp);
   FD_ZERO(&(ssp->set));
   ssp->highest=0;
@@ -873,16 +853,13 @@ void GWEN_SocketSet_free(GWEN_SOCKETSET *ssp) {
 
 
 
-GWEN_ERRORCODE GWEN_SocketSet_AddSocket(GWEN_SOCKETSET *ssp,
+int GWEN_SocketSet_AddSocket(GWEN_SOCKETSET *ssp,
                                         const GWEN_SOCKET *sp){
   assert(ssp);
   assert(sp);
   if (sp->socket==-1) {
     DBG_INFO(GWEN_LOGDOMAIN, "Socket is not connected, can not add");
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                          GWEN_SOCKET_ERROR_NOT_OPEN);
+    return GWEN_ERROR_NOT_OPEN;
   }
   ssp->highest=(ssp->highest<sp->socket)?sp->socket:ssp->highest;
   FD_SET(sp->socket,&(ssp->set));
@@ -892,7 +869,7 @@ GWEN_ERRORCODE GWEN_SocketSet_AddSocket(GWEN_SOCKETSET *ssp,
 
 
 
-GWEN_ERRORCODE GWEN_SocketSet_RemoveSocket(GWEN_SOCKETSET *ssp,
+int GWEN_SocketSet_RemoveSocket(GWEN_SOCKETSET *ssp,
                                            const GWEN_SOCKET *sp){
   assert(ssp);
   assert(sp);
@@ -926,6 +903,7 @@ GWEN_SOCKET *GWEN_Socket_new(GWEN_SOCKETTYPE socketType){
   GWEN_SOCKET *sp;
 
   GWEN_NEW_OBJECT(GWEN_SOCKET, sp);
+  GWEN_LIST_INIT(GWEN_SOCKET, sp);
   sp->type=socketType;
   return sp;
 }
@@ -934,13 +912,14 @@ GWEN_SOCKET *GWEN_Socket_new(GWEN_SOCKETTYPE socketType){
 
 void GWEN_Socket_free(GWEN_SOCKET *sp){
   if (sp) {
+    GWEN_LIST_FINI(GWEN_SOCKET, sp);
     GWEN_FREE_OBJECT(sp);
   }
 }
 
 
 
-GWEN_ERRORCODE GWEN_Socket_Open(GWEN_SOCKET *sp){
+int GWEN_Socket_Open(GWEN_SOCKET *sp){
   int s;
 
   assert(sp);
@@ -952,10 +931,7 @@ GWEN_ERRORCODE GWEN_Socket_Open(GWEN_SOCKET *sp){
     s=socket(AF_INET, SOCK_STREAM,0);
 #endif
     if (s==-1)
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                            WSAGetLastError());
+      return WSAGetLastError();
     sp->socket=s;
     break;
 
@@ -966,26 +942,17 @@ GWEN_ERRORCODE GWEN_Socket_Open(GWEN_SOCKET *sp){
     s=socket(AF_INET, SOCK_DGRAM,0);
 #endif
     if (s==-1)
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                            WSAGetLastError());
+      return WSAGetLastError();
     sp->socket=s;
     break;
 
   case GWEN_SocketTypeUnix:
     DBG_ERROR(GWEN_LOGDOMAIN, "No unix domain sockets available for this system");
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_INETADDR_ERROR_TYPE),
-                          GWEN_INETADDR_ERROR_BAD_ADDRESS_FAMILY);
+    return GWEN_ERROR_BAD_ADDRESS_FAMILY;
     break;
 
   default:
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                          GWEN_SOCKET_ERROR_BAD_SOCKETTYPE);
+    return GWEN_ERROR_BAD_SOCKETTYPE;
   } /* switch */
 
   return 0;
@@ -993,7 +960,7 @@ GWEN_ERRORCODE GWEN_Socket_Open(GWEN_SOCKET *sp){
 
 
 
-GWEN_ERRORCODE GWEN_Socket_Connect(GWEN_SOCKET *sp,
+int GWEN_Socket_Connect(GWEN_SOCKET *sp,
                                    const GWEN_INETADDRESS *addr){
   assert(sp);
   if (connect(sp->socket,
@@ -1004,76 +971,58 @@ GWEN_ERRORCODE GWEN_Socket_Connect(GWEN_SOCKET *sp,
       DBG_INFO(GWEN_LOGDOMAIN, "Error %d (%s)",
                 WSAGetLastError(),
 		h_strerror(WSAGetLastError()));
-      return GWEN_Error_new(0,
-			    GWEN_ERROR_SEVERITY_ERR,
-			    GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-			    WSAGetLastError());
+      return WSAGetLastError();
     }
     else
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                            GWEN_SOCKET_ERROR_IN_PROGRESS);
+      return GWEN_ERROR_IN_PROGRESS;
   }
   return 0;
 }
 
 
 
-GWEN_ERRORCODE GWEN_Socket_Close(GWEN_SOCKET *sp){
+int GWEN_Socket_Close(GWEN_SOCKET *sp){
   int rv;
 
   assert(sp);
   if (sp->socket==-1)
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                          GWEN_SOCKET_ERROR_NOT_OPEN);
+    return GWEN_ERROR_NOT_OPEN;
 
   rv=closesocket(sp->socket);
   sp->socket=-1;
   if (rv==-1)
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                          WSAGetLastError());
+    return WSAGetLastError();
   return 0;
 }
 
 
 
-GWEN_ERRORCODE GWEN_Socket_Bind(GWEN_SOCKET *sp,
+int GWEN_Socket_Bind(GWEN_SOCKET *sp,
                                 const GWEN_INETADDRESS *addr){
   assert(sp);
   assert(addr);
   if (bind(sp->socket,
 	   addr->address,
 	   addr->size))
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-			  WSAGetLastError());
+    return WSAGetLastError();
   return 0;
 }
 
 
 
-GWEN_ERRORCODE GWEN_Socket_Listen(GWEN_SOCKET *sp, int backlog){
+int GWEN_Socket_Listen(GWEN_SOCKET *sp, int backlog){
   assert(sp);
   if (listen(sp->socket, backlog))
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-			  WSAGetLastError());
+    return WSAGetLastError();
   return 0;
 }
 
 
 
-GWEN_ERRORCODE GWEN_Socket_Accept(GWEN_SOCKET *sp,
-                                  GWEN_INETADDRESS **newaddr,
-                                  GWEN_SOCKET **newsock){
-  unsigned int addrlen;
+int GWEN_Socket_Accept(GWEN_SOCKET *sp,
+		       GWEN_INETADDRESS **newaddr,
+		       GWEN_SOCKET **newsock){
+  int addrlen;
   GWEN_INETADDRESS *localAddr;
   GWEN_SOCKET *localSocket;
   GWEN_AddressFamily af;
@@ -1091,10 +1040,7 @@ GWEN_ERRORCODE GWEN_Socket_Accept(GWEN_SOCKET *sp,
     af=GWEN_AddressFamilyUnix;
     break;
   default:
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                          GWEN_SOCKET_ERROR_BAD_SOCKETTYPE);
+    return GWEN_ERROR_BAD_SOCKETTYPE;
   } /* switch */
 
   localAddr=GWEN_InetAddr_new(af);
@@ -1107,15 +1053,9 @@ GWEN_ERRORCODE GWEN_Socket_Accept(GWEN_SOCKET *sp,
     GWEN_InetAddr_free(localAddr);
     GWEN_Socket_free(localSocket);
     if (WSAGetLastError()==WSAEWOULDBLOCK)
-      return GWEN_Error_new(0,
-			    GWEN_ERROR_SEVERITY_ERR,
-			    GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-			    GWEN_SOCKET_ERROR_TIMEOUT);
+      return GWEN_ERROR_TIMEOUT;
     else
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-			    GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-			    WSAGetLastError());
+      return WSAGetLastError();
   }
   localSocket->type=sp->type;
   localAddr->size=addrlen;
@@ -1126,9 +1066,9 @@ GWEN_ERRORCODE GWEN_Socket_Accept(GWEN_SOCKET *sp,
 
 
 
-GWEN_ERRORCODE GWEN_Socket_GetPeerAddr(GWEN_SOCKET *sp,
+int GWEN_Socket_GetPeerAddr(GWEN_SOCKET *sp,
                                        GWEN_INETADDRESS **newaddr){
-  unsigned int addrlen;
+  int addrlen;
   GWEN_INETADDRESS *localAddr;
   GWEN_AddressFamily af;
 
@@ -1144,22 +1084,16 @@ GWEN_ERRORCODE GWEN_Socket_GetPeerAddr(GWEN_SOCKET *sp,
     af=GWEN_AddressFamilyUnix;
     break;
   default:
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                          GWEN_SOCKET_ERROR_BAD_SOCKETTYPE);
+    return GWEN_ERROR_BAD_SOCKETTYPE;
   } /* switch */
 
   localAddr=GWEN_InetAddr_new(af);
   addrlen=localAddr->size;
 
   if (getpeername(sp->socket,
-                  localAddr->address, &addrlen)) {
+		  localAddr->address, &addrlen)) {
     GWEN_InetAddr_free(localAddr);
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                          WSAGetLastError());
+    return WSAGetLastError();
   }
   localAddr->size=addrlen;
   *newaddr=localAddr;
@@ -1168,7 +1102,7 @@ GWEN_ERRORCODE GWEN_Socket_GetPeerAddr(GWEN_SOCKET *sp,
 
 
 
-GWEN_ERRORCODE GWEN_Socket_Select(GWEN_SOCKETSET *rs,
+int GWEN_Socket_Select(GWEN_SOCKETSET *rs,
                                   GWEN_SOCKETSET *ws,
                                   GWEN_SOCKETSET *xs,
                                   int timeout){
@@ -1206,28 +1140,19 @@ GWEN_ERRORCODE GWEN_Socket_Select(GWEN_SOCKETSET *rs,
   if (rv<0) {
     /* error */
     if (WSAGetLastError()==WSAEINTR)
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                            GWEN_SOCKET_ERROR_INTERRUPTED);
+      return GWEN_ERROR_INTERRUPTED;
     else
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                            WSAGetLastError());
+      return WSAGetLastError();
   }
   if (rv==0)
     /* timeout */
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                          GWEN_SOCKET_ERROR_TIMEOUT);
+    return GWEN_ERROR_TIMEOUT;
   return 0;
 }
 
 
 
-GWEN_ERRORCODE GWEN_Socket_Read(GWEN_SOCKET *sp,
+int GWEN_Socket_Read(GWEN_SOCKET *sp,
                                 char *buffer,
                                 int *bsize){
   int i;
@@ -1238,20 +1163,11 @@ GWEN_ERRORCODE GWEN_Socket_Read(GWEN_SOCKET *sp,
   i=recv(sp->socket,buffer, *bsize,0);
   if (i<0) {
     if (WSAGetLastError()==WSAEWOULDBLOCK)
-      return GWEN_Error_new(0,
-			    GWEN_ERROR_SEVERITY_ERR,
-			    GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-			    GWEN_SOCKET_ERROR_TIMEOUT);
+      return GWEN_ERROR_TIMEOUT;
     else if (WSAGetLastError()==WSAEINTR)
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                            GWEN_SOCKET_ERROR_INTERRUPTED);
+      return GWEN_ERROR_INTERRUPTED;
     else
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-			    WSAGetLastError());
+      return WSAGetLastError();
   }
   *bsize=i;
   return 0;
@@ -1259,7 +1175,7 @@ GWEN_ERRORCODE GWEN_Socket_Read(GWEN_SOCKET *sp,
 
 
 
-GWEN_ERRORCODE GWEN_Socket_Write(GWEN_SOCKET *sp,
+int GWEN_Socket_Write(GWEN_SOCKET *sp,
                                  const char *buffer,
                                  int *bsize){
   int i;
@@ -1274,20 +1190,11 @@ GWEN_ERRORCODE GWEN_Socket_Write(GWEN_SOCKET *sp,
 #endif
   if (i<0) {
     if (WSAGetLastError()==WSAEWOULDBLOCK)
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                            GWEN_SOCKET_ERROR_TIMEOUT);
+      return GWEN_ERROR_TIMEOUT;
     else if (WSAGetLastError()==WSAEINTR)
-      return GWEN_Error_new(0,
-			    GWEN_ERROR_SEVERITY_ERR,
-			    GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-			    GWEN_SOCKET_ERROR_INTERRUPTED);
+      return GWEN_ERROR_INTERRUPTED;
     else
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-			    GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-			    WSAGetLastError());
+      return WSAGetLastError();
   }
   *bsize=i;
   return 0;
@@ -1295,11 +1202,11 @@ GWEN_ERRORCODE GWEN_Socket_Write(GWEN_SOCKET *sp,
 
 
 
-GWEN_ERRORCODE GWEN_Socket_ReadFrom(GWEN_SOCKET *sp,
+int GWEN_Socket_ReadFrom(GWEN_SOCKET *sp,
                                     GWEN_INETADDRESS **newaddr,
                                     char *buffer,
                                     int *bsize){
-  unsigned int addrlen;
+  int addrlen;
   int i;
   GWEN_INETADDRESS *localAddr;
   GWEN_AddressFamily af;
@@ -1318,10 +1225,7 @@ GWEN_ERRORCODE GWEN_Socket_ReadFrom(GWEN_SOCKET *sp,
     af=GWEN_AddressFamilyUnix;
     break;
   default:
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                          GWEN_SOCKET_ERROR_BAD_SOCKETTYPE);
+    return GWEN_ERROR_BAD_SOCKETTYPE;
   } /* switch */
 
   localAddr=GWEN_InetAddr_new(af);
@@ -1336,20 +1240,11 @@ GWEN_ERRORCODE GWEN_Socket_ReadFrom(GWEN_SOCKET *sp,
   if (i<0) {
     GWEN_InetAddr_free(localAddr);
     if (WSAGetLastError()==WSAEWOULDBLOCK)
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                            GWEN_SOCKET_ERROR_TIMEOUT);
+      return GWEN_ERROR_TIMEOUT;
     else if (WSAGetLastError()==WSAEINTR)
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                            GWEN_SOCKET_ERROR_INTERRUPTED);
+      return GWEN_ERROR_INTERRUPTED;
     else
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                            WSAGetLastError());
+      return WSAGetLastError();
   }
   *bsize=i;
   localAddr->size=addrlen;
@@ -1359,7 +1254,7 @@ GWEN_ERRORCODE GWEN_Socket_ReadFrom(GWEN_SOCKET *sp,
 
 
 
-GWEN_ERRORCODE GWEN_Socket_WriteTo(GWEN_SOCKET *sp,
+int GWEN_Socket_WriteTo(GWEN_SOCKET *sp,
                                    const GWEN_INETADDRESS *addr,
                                    const char *buffer,
                                    int *bsize){
@@ -1381,20 +1276,11 @@ GWEN_ERRORCODE GWEN_Socket_WriteTo(GWEN_SOCKET *sp,
            addr->size);
   if (i<0) {
     if (WSAGetLastError()==WSAEWOULDBLOCK)
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                            GWEN_SOCKET_ERROR_TIMEOUT);
+      return GWEN_ERROR_TIMEOUT;
     else if (WSAGetLastError()==WSAEINTR)
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                            GWEN_SOCKET_ERROR_INTERRUPTED);
+      return GWEN_ERROR_INTERRUPTED;
     else
-      return GWEN_Error_new(0,
-                            GWEN_ERROR_SEVERITY_ERR,
-                            GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                            WSAGetLastError());
+      return WSAGetLastError();
   }
   *bsize=i;
   return 0;
@@ -1402,7 +1288,7 @@ GWEN_ERRORCODE GWEN_Socket_WriteTo(GWEN_SOCKET *sp,
 
 
 
-GWEN_ERRORCODE GWEN_Socket_SetBlocking(GWEN_SOCKET *sp,
+int GWEN_Socket_SetBlocking(GWEN_SOCKET *sp,
                                        int b) {
   unsigned long fl;
 
@@ -1412,17 +1298,14 @@ GWEN_ERRORCODE GWEN_Socket_SetBlocking(GWEN_SOCKET *sp,
     DBG_INFO(GWEN_LOGDOMAIN, "Error %d (%s)",
               WSAGetLastError(),
               h_strerror(WSAGetLastError()));
-    return GWEN_Error_new(0,
-                     GWEN_ERROR_SEVERITY_ERR,
-                     GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                     WSAGetLastError());
+    return WSAGetLastError();
   }
   return 0;
 }
 
 
 
-GWEN_ERRORCODE GWEN_Socket_SetBroadcast(GWEN_SOCKET *sp,
+int GWEN_Socket_SetBroadcast(GWEN_SOCKET *sp,
                                         int fl) {
 
   assert(sp);
@@ -1433,16 +1316,13 @@ GWEN_ERRORCODE GWEN_Socket_SetBroadcast(GWEN_SOCKET *sp,
 		 SO_BROADCAST,
 		 (const char*)&fl,
 		 sizeof(fl)))
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                          WSAGetLastError());
+    return WSAGetLastError();
   return 0;
 }
 
 
 
-GWEN_ERRORCODE GWEN_Socket_SetReuseAddress(GWEN_SOCKET *sp, int fl){
+int GWEN_Socket_SetReuseAddress(GWEN_SOCKET *sp, int fl){
 	assert(sp);
 
   /*if (sp->type==SocketTypeUnix)
@@ -1453,74 +1333,69 @@ GWEN_ERRORCODE GWEN_Socket_SetReuseAddress(GWEN_SOCKET *sp, int fl){
 		 SO_REUSEADDR,
 		 (const char*)&fl,
 		 sizeof(fl)))
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                          WSAGetLastError());
+    return WSAGetLastError();
   return 0;
 }
 
 
 
-GWEN_ERRORCODE GWEN_Socket_GetSocketError(GWEN_SOCKET *sp) {
+int GWEN_Socket_GetSocketError(GWEN_SOCKET *sp) {
   int rv;
-  unsigned int rvs;
+  int rvs;
 
   assert(sp);
   rvs=sizeof(rv);
-  if (-1==getsockopt(sp->socket,SOL_SOCKET,SO_ERROR,(char*)&rv,&rvs))
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                          WSAGetLastError());
-  if (rv!=0)
-    return GWEN_Error_new(0,
-                          GWEN_ERROR_SEVERITY_ERR,
-                          GWEN_Error_FindType(GWEN_SOCKET_ERROR_TYPE),
-                          rv);
+  if (-1==getsockopt(sp->socket,SOL_SOCKET,SO_ERROR,(char*)&rv,&rvs)) {
+    DBG_INFO(GWEN_LOGDOMAIN, "getsockopt(): %s", h_strerror(WSAGetLastError()));
+    return GWEN_ERROR_IO;
+  }
+
+  if (rv) {
+    switch(rv) {
+    case WSAEWOULDBLOCK: return GWEN_ERROR_TIMEOUT;
+    case WSAEINTR:       return GWEN_ERROR_INTERRUPTED;
+    default:
+      DBG_INFO(GWEN_LOGDOMAIN, "getsockopt(): %d (%s)", rv, h_strerror(rv));
+      return GWEN_ERROR_IO;
+    }
+  }
+
   return 0;
 }
 
 
 
-GWEN_ERRORCODE GWEN_Socket_WaitForRead(GWEN_SOCKET *sp,
-                                       int timeout) {
-  GWEN_ERRORCODE err;
+int GWEN_Socket_WaitForRead(GWEN_SOCKET *sp, int timeout) {
+  int err;
   GWEN_SOCKETSET *set;
 
   set=GWEN_SocketSet_new();
 
   err=GWEN_SocketSet_AddSocket(set,sp);
-  if (!GWEN_Error_IsOk(err)) {
+  if (err) {
     GWEN_SocketSet_free(set);
     return err;
   }
   err=GWEN_Socket_Select(set,0,0,timeout);
   GWEN_SocketSet_free(set);
-  if (GWEN_Error_IsOk(err)) {
-    return 0;
-  }
 
   return err;
 }
 
 
 
-GWEN_ERRORCODE GWEN_Socket_WaitForWrite(GWEN_SOCKET *sp,
-                                        int timeout) {
-  GWEN_ERRORCODE err;
+int GWEN_Socket_WaitForWrite(GWEN_SOCKET *sp, int timeout) {
+  int err;
   GWEN_SOCKETSET *set;
 
   set=GWEN_SocketSet_new();
   err=GWEN_SocketSet_AddSocket(set,sp);
-  if (!GWEN_Error_IsOk(err)) {
+  if (err) {
     GWEN_SocketSet_free(set);
     return err;
   }
   err=GWEN_Socket_Select(0,set,0,timeout);
   GWEN_SocketSet_free(set);
-  if (GWEN_Error_IsOk(err))
-    return 0;
 
   return err;
 }
