@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: init.c 359 2004-05-07 13:42:36Z cstim $
+    cvs         : $Id: init.c 1393 2007-11-22 18:26:05Z martin $
     begin       : Wed Mar 27 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -46,12 +46,12 @@
 BOOL APIENTRY DllMain(HINSTANCE hInst,
                       DWORD reason,
                       LPVOID reserved) {
-  GWEN_ERRORCODE err;
+  int err;
 
   switch (reason) {
   case DLL_PROCESS_ATTACH:
     err=GWEN_Init();
-    if (!GWEN_Error_IsOk(err)) {
+    if (err) {
       fprintf(stderr, "Could not initialize Gwenhywfar, aborting\n");
       return FALSE;
     }
@@ -61,7 +61,7 @@ BOOL APIENTRY DllMain(HINSTANCE hInst,
 
   case DLL_PROCESS_DETACH:
     err=GWEN_Fini();
-    if (!GWEN_Error_IsOk(err)) {
+    if (err) {
       fprintf(stderr, "Could not deinitialize Gwenhywfar\n");
     }
     /* DEBUG */
