@@ -1,7 +1,7 @@
 /***************************************************************************
   $RCSfile$
                              -------------------
-    cvs         : $Id: libloader_p.h 923 2005-11-19 03:35:10Z aquamaniac $
+    cvs         : $Id: libloader_p.h 1393 2007-11-22 18:26:05Z martin $
     begin       : Fri Nov 22 2002
     copyright   : (C) 2002 by Martin Preuss
     email       : martin@libchipcard.de
@@ -36,27 +36,16 @@
 #include <gwenhywfar/libloader.h>
 
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
-
-GWENHYWFAR_API struct GWEN_LIBLOADERSTRUCT {
+struct GWEN_LIBLOADER {
   void *handle;
 };
 
 
-GWEN_ERRORCODE GWEN_LibLoader_LoadLibrary(GWEN_LIBLOADER *h,
-                                          const char *name);
+int GWEN_LibLoader_LoadLibrary(GWEN_LIBLOADER *h, const char *name);
 
-GWEN_ERRORCODE GWEN_LibLoader__OpenLibraryWithPath(GWEN_LIBLOADER *h,
-                                                   const char *path,
-                                                   const char *name);
-
-
-#ifdef __cplusplus
-}
-#endif
+int GWEN_LibLoader__OpenLibraryWithPath(GWEN_LIBLOADER *h,
+					const char *path,
+					const char *name);
 
 
 #endif /* GWENHYWFAR_LIBLOADER_P_H */
