@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: dbio_l.h 349 2004-05-06 11:02:04Z aquamaniac $
+ cvs         : $Id: dbio_l.h 1393 2007-11-22 18:26:05Z martin $
  begin       : Wed Mar 31 2004
  copyright   : (C) 2004 by Martin Preuss
  email       : martin@libchipcard.de
@@ -32,11 +32,11 @@
 #define GWENHYWFAR_DBIO_L_H
 
 
-#include <gwenhywfar/dbio.h>
+#include <gwenhywfar/dbio_be.h>
 
 
-GWEN_ERRORCODE GWEN_DBIO_ModuleInit();
-GWEN_ERRORCODE GWEN_DBIO_ModuleFini();
+int GWEN_DBIO_ModuleInit();
+int GWEN_DBIO_ModuleFini();
 
 
 #endif /* GWENHYWFAR_DBIO_P_H */
