@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: path.c 667 2005-01-14 13:40:10Z aquamaniac $
+ cvs         : $Id: path.c 1393 2007-11-22 18:26:05Z martin $
  begin       : Tue Sep 09 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -41,7 +41,7 @@
 
 void *GWEN_Path_Handle(const char *path,
                        void *data,
-                       GWEN_TYPE_UINT32 flags,
+                       uint32_t flags,
                        GWEN_PATHHANDLERPTR elementFunction) {
   GWEN_BUFFER *buf1;
   int i;
@@ -192,7 +192,7 @@ void *GWEN_Path_Handle(const char *path,
 
 void *GWEN_Path_HandleWithIdx(const char *path,
                               void *data,
-                              GWEN_TYPE_UINT32 flags,
+                              uint32_t flags,
                               GWEN_PATHIDXHANDLERPTR elementFunction) {
   GWEN_BUFFER *buf1;
   int i;
@@ -392,7 +392,7 @@ void *GWEN_Path_AppendPathElement(const char *entry,
 
 int GWEN_Path_Convert(const char *path,
                       GWEN_BUFFER *buffer,
-                      GWEN_TYPE_UINT32 flags) {
+                      uint32_t flags) {
   void *p;
 
   p=GWEN_Path_Handle(path,
