@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
  -------------------
- cvs         : $Id: text.c 1088 2006-09-20 17:05:48Z martin $
+ cvs         : $Id: text.c 1402 2008-01-15 20:50:45Z martin $
  begin       : Sat Jun 28 2003
  copyright   : (C) 2003 by Martin Preuss
  email       : martin@libchipcard.de
@@ -63,7 +63,7 @@ char *GWEN_Text_GetWord(const char *src,
                         const char *delims,
                         char *buffer,
                         unsigned int maxsize,
-                        GWEN_TYPE_UINT32 flags,
+                        uint32_t flags,
                         const char **next){
   unsigned int size;
   int lastWasBlank;
@@ -187,7 +187,7 @@ char *GWEN_Text_GetWord(const char *src,
 int GWEN_Text_GetWordToBuffer(const char *src,
                               const char *delims,
                               GWEN_BUFFER *buf,
-                              GWEN_TYPE_UINT32 flags,
+                              uint32_t flags,
                               const char **next){
   int lastWasBlank;
   int lastBlankPos;
@@ -196,8 +196,13 @@ int GWEN_Text_GetWordToBuffer(const char *src,
 
   /* skip leading blanks, if wanted */
   if (flags & GWEN_TEXT_FLAGS_DEL_LEADING_BLANKS) {
-    while(*src && (unsigned char)(*src)<33)
+    while(*src && (unsigned char)(*src)<33) {
+      if (strchr(delims, *src)) {
+	*next=src;
+	return 0;
+      }
       src++;
+    }
   }
 
   /* get word */
@@ -1751,8 +1756,8 @@ int GWEN_Text_CountUtf8Chars(const char *s, int len) {
 
 int GWEN_Text_UnescapeXmlToBuffer(const char *src, GWEN_BUFFER *buf) {
   char *pdst;
-  GWEN_TYPE_UINT32 roomLeft;
-  GWEN_TYPE_UINT32 bytesAdded;
+  uint32_t roomLeft;
+  uint32_t bytesAdded;
 
 #define GWEN_TEXT__APPENDCHAR(chr)                     \
   if (roomLeft<2) {                                   \
