@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: tlv.c 790 2005-07-23 09:32:08Z aquamaniac $
+    cvs         : $Id: tlv.c 1393 2007-11-22 18:26:05Z martin $
     begin       : Sun Jun 13 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -138,7 +138,7 @@ GWEN_TLV *GWEN_TLV_fromBuffer(GWEN_BUFFER *mbuf, int isBerTlv) {
   unsigned int pos;
   unsigned int j;
   GWEN_TLV *tlv;
-  GWEN_TYPE_UINT32 startPos;
+  uint32_t startPos;
 
   if (!GWEN_Buffer_GetBytesLeft(mbuf)) {
     DBG_ERROR(GWEN_LOGDOMAIN, "Buffer empty");
