@@ -1,7 +1,7 @@
 /***************************************************************************
  $RCSfile$
                              -------------------
-    cvs         : $Id: types.h.in 975 2006-01-31 10:39:34Z cstim $
+    cvs         : $Id: types.h.in 1393 2007-11-22 18:26:05Z martin $
     begin       : Sun Jan 04 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -28,39 +28,7 @@
 #ifndef GWENHYWFAR_TYPES_H
 #define GWENHYWFAR_TYPES_H
 
-/** define type templates */
-#define GWEN_TYPE_TMPL_UINT32 "%u"
-#define GWEN_TYPE_TMPL_UINT64 "%llu"
-
-
-/** Define an unsigned integer type with 32 bit storage length. */
-typedef unsigned int GWEN_TYPE_UINT32;
-
-/* Here we provide G_GNUC_EXTENSION as an alias for __extension__,
- * where this is valid. This allows for warningless compilation of
- * "long long" types even in the presence of '-ansi -pedantic'. Copied
- * from glib-2.0's gmacros.h.
- */
-#if     __GNUC__ > 2 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 8)
-#  define GWEN_GNUC_EXTENSION __extension__
-#else
-#  define GWEN_GNUC_EXTENSION
-#endif
-
-/** Define an unsigned integer type with 64 bit storage length.
- *
- *  This depends heavily on the actual compiler. Currently gcc and
- *  MSVC are supported. For any further compilers, additional
- *  conditional clauses have to be added. */
-#ifdef __GNUC__
-  GWEN_GNUC_EXTENSION
-  typedef unsigned long long GWEN_TYPE_UINT64;
-#else /* __GNUC__ */
-# include <windows.h>
-  /* Workaround for Microsoft Visual Studio Compiler (MSVC) which does
-   * not have "long long" but ULONG64 instead. */
-  typedef ULONG64 GWEN_TYPE_UINT64;
-#endif /* __GNUC__ */
+#include <inttypes.h>
 
 
 #define GWENHYWFAR_SYS_IS_WINDOWS 0
