@@ -1,7 +1,7 @@
 /***************************************************************************
- $RCSfile: main.c,v $
+ $RCSfile$
                              -------------------
-    cvs         : $Id: main.c,v 1.9 2005/10/13 05:22:49 aquamaniac Exp $
+    cvs         : $Id: main.c 1393 2007-11-22 18:26:05Z martin $
     begin       : Mon Mar 01 2004
     copyright   : (C) 2004 by Martin Preuss
     email       : martin@libchipcard.de
@@ -45,51 +45,83 @@
 
 
 
+int write_xml_to_bio(GWEN_XMLNODE *n, GWEN_BUFFEREDIO *bio, uint32_t flags) {
+  GWEN_BUFFER *buf;
+  int rv;
+  unsigned int bsize;
+
+  buf=GWEN_Buffer_new(0, 256, 0, 1);
+  rv=GWEN_XMLNode_toBuffer(n, buf, flags);
+  if (rv) {
+    GWEN_Buffer_free(buf);
+    return rv;
+  }
+
+  bsize=GWEN_Buffer_GetUsedBytes(buf);
+  rv=GWEN_BufferedIO_WriteRawForced(bio, GWEN_Buffer_GetStart(buf), &bsize);
+  GWEN_Buffer_free(buf);
+  return rv;
+}
+
+
+
 int write_h_header(ARGUMENTS *args, GWEN_XMLNODE *node,
-		   GWEN_BUFFEREDIO *bio) {
+                   GWEN_BUFFEREDIO *bio,
+		   const char *where) {
   int isSys;
-  GWEN_ERRORCODE err;
+  int err;
   const char *d;
   GWEN_XMLNODE *dn;
+  /*const char *nwhere;*/
 
+  /*nwhere=GWEN_XMLNode_GetProperty(node, "out", "header");
+  if (strcasecmp(nwhere, where)==0) {*/
   dn=GWEN_XMLNode_GetFirstData(node);
   if (!dn) {
-    DBG_ERROR(0, "Empty <header>");
-    return -1;
+      DBG_ERROR(0, "Empty <header>");
+      return -1;
   }
   d=GWEN_XMLNode_GetData(dn);
   if (!d) {
-    DBG_ERROR(0, "Empty <header>");
-    return -1;
+      DBG_ERROR(0, "Empty <header>");
+      return -1;
   }
   isSys=(strcasecmp(GWEN_XMLNode_GetProperty(node, "type", ""),
-		    "sys")==0);
+                    "sys")==0);
 
   err=GWEN_BufferedIO_Write(bio, "#include ");
-  if (!GWEN_Error_IsOk(err)) { DBG_ERROR_ERR(0, err); return -1;}
+  if (err) { DBG_ERROR_ERR(0, err); return -1;}
   if (isSys) {
-    err=GWEN_BufferedIO_Write(bio, "<");
-    if (!GWEN_Error_IsOk(err)) { DBG_ERROR_ERR(0, err); return -1;}
+      err=GWEN_BufferedIO_Write(bio, "<");
+      if (err) { DBG_ERROR_ERR(0, err); return -1;}
   }
   else {
-    err=GWEN_BufferedIO_Write(bio, "\"");
-    if (!GWEN_Error_IsOk(err)) { DBG_ERROR_ERR(0, err); return -1;}
+      err=GWEN_BufferedIO_Write(bio, "\"");
+      if (err) { DBG_ERROR_ERR(0, err); return -1;}
   }
   err=GWEN_BufferedIO_Write(bio, d);
-  if (!GWEN_Error_IsOk(err)) { DBG_ERROR_ERR(0, err); return -1;}
+  if (err) { DBG_ERROR_ERR(0, err); return -1;}
   if (isSys) {
-    err=GWEN_BufferedIO_WriteLine(bio, ">");
-    if (!GWEN_Error_IsOk(err)) { DBG_ERROR_ERR(0, err); return -1;}
+      err=GWEN_BufferedIO_WriteLine(bio, ">");
+      if (err) { DBG_ERROR_ERR(0, err); return -1;}
   }
   else {
-    err=GWEN_BufferedIO_WriteLine(bio, "\"");
-    if (!GWEN_Error_IsOk(err)) { DBG_ERROR_ERR(0, err); return -1;}
+      err=GWEN_BufferedIO_WriteLine(bio, "\"");
+      if (err) { DBG_ERROR_ERR(0, err); return -1;}
   }
+  /*} */
 
   return 0;
 }
 
 
+void write_if_nonnull(GWEN_BUFFEREDIO *bio, const char *str) {
+  if (str) {
+    GWEN_BufferedIO_Write(bio, str);
+    GWEN_BufferedIO_Write(bio, " ");
+  }
+}
+
 
 int write_h_setget_c(ARGUMENTS *args,
                      GWEN_XMLNODE *node,
@@ -129,9 +161,9 @@ int write_h_setget_c(ARGUMENTS *args,
           dn=GWEN_XMLNode_FindFirstTag(n, "descr", 0, 0);
           if (dn) {
             GWEN_BufferedIO_WriteLine(bio, " *");
-            if (GWEN_XMLNode_WriteToStream(dn, bio,
+            if (write_xml_to_bio(dn, bio,
                                            GWEN_XML_FLAGS_SIMPLE |
-                                           GWEN_XML_FLAGS_INDENT))
+					   GWEN_XML_FLAGS_INDENT))
               return -1;
           }
           GWEN_BufferedIO_WriteLine(bio, "*/");
@@ -192,10 +224,7 @@ int write_h_setget_c(ARGUMENTS *args,
           GWEN_BufferedIO_WriteChar(bio, toupper(*name));
           GWEN_BufferedIO_WriteLine(bio, name+1);
           GWEN_BufferedIO_WriteLine(bio, "*/");
-          if (args->domain) {
-            GWEN_BufferedIO_Write(bio, args->domain);
-            GWEN_BufferedIO_Write(bio, " ");
-          }
+          write_if_nonnull(bio, args->domain);
           if (isPtr &&
               (/*strcasecmp(mode, "single")==0 ||*/ isConst)) {
             GWEN_BufferedIO_Write(bio, "const ");
@@ -237,10 +266,7 @@ int write_h_setget_c(ARGUMENTS *args,
           GWEN_BufferedIO_WriteChar(bio, toupper(*name));
           GWEN_BufferedIO_WriteLine(bio, name+1);
           GWEN_BufferedIO_WriteLine(bio, "*/");
-          if (args->domain) {
-            GWEN_BufferedIO_Write(bio, args->domain);
-            GWEN_BufferedIO_Write(bio, " ");
-          }
+          write_if_nonnull(bio, args->domain);
           GWEN_BufferedIO_Write(bio, "void ");
           GWEN_BufferedIO_Write(bio, prefix);
           GWEN_BufferedIO_Write(bio, "_Set");
@@ -279,10 +305,7 @@ int write_h_setget_c(ARGUMENTS *args,
 
           if (strcasecmp(typ, "GWEN_STRINGLIST")==0) {
             /* special functions for string lists */
-            if (args->domain) {
-              GWEN_BufferedIO_Write(bio, args->domain);
-              GWEN_BufferedIO_Write(bio, " ");
-            }
+	    write_if_nonnull(bio, args->domain);
             GWEN_BufferedIO_Write(bio, "void ");
             GWEN_BufferedIO_Write(bio, prefix);
             GWEN_BufferedIO_Write(bio, "_Add");
@@ -292,10 +315,7 @@ int write_h_setget_c(ARGUMENTS *args,
             GWEN_BufferedIO_Write(bio, styp);
             GWEN_BufferedIO_WriteLine(bio, " *st, const char *d, int chk);");
 
-            if (args->domain) {
-              GWEN_BufferedIO_Write(bio, args->domain);
-              GWEN_BufferedIO_Write(bio, " ");
-            }
+	    write_if_nonnull(bio, args->domain);
             GWEN_BufferedIO_Write(bio, "void ");
             GWEN_BufferedIO_Write(bio, prefix);
             GWEN_BufferedIO_Write(bio, "_Remove");
@@ -305,10 +325,7 @@ int write_h_setget_c(ARGUMENTS *args,
             GWEN_BufferedIO_Write(bio, styp);
             GWEN_BufferedIO_WriteLine(bio, " *st, const char *d);");
 
-            if (args->domain) {
-              GWEN_BufferedIO_Write(bio, args->domain);
-              GWEN_BufferedIO_Write(bio, " ");
-            }
+	    write_if_nonnull(bio, args->domain);
             GWEN_BufferedIO_Write(bio, "void ");
             GWEN_BufferedIO_Write(bio, prefix);
             GWEN_BufferedIO_Write(bio, "_Clear");
@@ -318,10 +335,7 @@ int write_h_setget_c(ARGUMENTS *args,
             GWEN_BufferedIO_Write(bio, styp);
             GWEN_BufferedIO_WriteLine(bio, " *st);");
 
-            if (args->domain) {
-              GWEN_BufferedIO_Write(bio, args->domain);
-              GWEN_BufferedIO_Write(bio, " ");
-            }
+	    write_if_nonnull(bio, args->domain);
             GWEN_BufferedIO_Write(bio, "int ");
             GWEN_BufferedIO_Write(bio, prefix);
             GWEN_BufferedIO_Write(bio, "_Has");
@@ -374,10 +388,7 @@ int write_h_setget_c(ARGUMENTS *args,
           GWEN_BufferedIO_WriteChar(bio, toupper(*name));
           GWEN_BufferedIO_WriteLine(bio, name+1);
           GWEN_BufferedIO_WriteLine(bio, "*/");
-          if (args->domain) {
-            GWEN_BufferedIO_Write(bio, args->domain);
-            GWEN_BufferedIO_Write(bio, " ");
-          }
+          write_if_nonnull(bio, args->domain);
 
           GWEN_BufferedIO_Write(bio, styp);
           GWEN_BufferedIO_Write(bio, "_");
@@ -399,10 +410,7 @@ int write_h_setget_c(ARGUMENTS *args,
           GWEN_BufferedIO_WriteChar(bio, toupper(*name));
           GWEN_BufferedIO_WriteLine(bio, name+1);
           GWEN_BufferedIO_WriteLine(bio, "*/");
-          if (args->domain) {
-            GWEN_BufferedIO_Write(bio, args->domain);
-            GWEN_BufferedIO_Write(bio, " ");
-          }
+          write_if_nonnull(bio, args->domain);
           GWEN_BufferedIO_Write(bio, "void ");
           GWEN_BufferedIO_Write(bio, prefix);
           GWEN_BufferedIO_Write(bio, "_Set");
@@ -421,10 +429,7 @@ int write_h_setget_c(ARGUMENTS *args,
           GWEN_BufferedIO_WriteLine(bio, "/**");
           /* TODO: Write API doc for this function */
           GWEN_BufferedIO_WriteLine(bio, "*/");
-          if (args->domain) {
-            GWEN_BufferedIO_Write(bio, args->domain);
-            GWEN_BufferedIO_Write(bio, " ");
-          }
+          write_if_nonnull(bio, args->domain);
           GWEN_BufferedIO_Write(bio, rettype);
           if (isPtr)
             GWEN_BufferedIO_Write(bio, "*");
@@ -493,8 +498,8 @@ int write_h_enums(ARGUMENTS *args, GWEN_XMLNODE *node,
   if (n) {
     GWEN_BUFFER *tprefix;
     GWEN_BUFFER *tid;
-    GWEN_TYPE_UINT32 ppos;
-    GWEN_TYPE_UINT32 tpos;
+    uint32_t ppos;
+    uint32_t tpos;
     const char *s;
 
     tprefix=GWEN_Buffer_new(0, 64, 0, 1);
@@ -533,7 +538,7 @@ int write_h_enums(ARGUMENTS *args, GWEN_XMLNODE *node,
 	if (nn)
 	  nn=GWEN_XMLNode_FindFirstTag(nn, "value", 0, 0);
 	if (nn) {
-	  GWEN_TYPE_UINT32 vpos;
+	  uint32_t vpos;
 
 	  vpos=GWEN_Buffer_GetPos(tprefix);
 	  while(nn) {
@@ -553,7 +558,7 @@ int write_h_enums(ARGUMENTS *args, GWEN_XMLNODE *node,
             dn=GWEN_XMLNode_FindFirstTag(nn, "descr", 0, 0);
             if (dn) {
               GWEN_BufferedIO_Write(bio, "  /** ");
-              if (GWEN_XMLNode_WriteToStream(dn, bio,
+              if (write_xml_to_bio(dn, bio,
                                              GWEN_XML_FLAGS_SIMPLE |
                                              GWEN_XML_FLAGS_INDENT))
                 return -1;
@@ -583,11 +588,13 @@ int write_h_enums(ARGUMENTS *args, GWEN_XMLNODE *node,
 	GWEN_BufferedIO_WriteLine(bio, ";");
 	GWEN_BufferedIO_WriteLine(bio, "");
 
+	write_if_nonnull(bio, args->domain);
 	GWEN_BufferedIO_Write(bio, GWEN_Buffer_GetStart(tid));
 	GWEN_BufferedIO_Write(bio, " ");
 	GWEN_BufferedIO_Write(bio, GWEN_Buffer_GetStart(tprefix));
 	GWEN_BufferedIO_WriteLine(bio, "_fromString(const char *s);");
 
+	write_if_nonnull(bio, args->domain);
 	GWEN_BufferedIO_Write(bio, "const char *");
 	GWEN_BufferedIO_Write(bio, GWEN_Buffer_GetStart(tprefix));
 	GWEN_BufferedIO_Write(bio, "_toString(");
@@ -768,7 +775,7 @@ int write_apidocrec_c(ARGUMENTS *args,
         GWEN_BufferedIO_WriteLine(bio, "<p>");
         dn=GWEN_XMLNode_FindFirstTag(n, "descr", 0, 0);
         if (dn) {
-          if (GWEN_XMLNode_WriteToStream(dn, bio,
+          if (write_xml_to_bio(dn, bio,
                                          GWEN_XML_FLAGS_SIMPLE |
                                          GWEN_XML_FLAGS_INDENT))
             return -1;
@@ -818,7 +825,7 @@ int write_apidocrec_c(ARGUMENTS *args,
           dn=GWEN_XMLNode_FindFirstTag(n, "brief", 0, 0);
           if (dn) {
             GWEN_BufferedIO_Write(bio, "@short ");
-            if (GWEN_XMLNode_WriteToStream(dn, bio,
+            if (write_xml_to_bio(dn, bio,
                                            GWEN_XML_FLAGS_SIMPLE |
                                            GWEN_XML_FLAGS_INDENT))
               return -1;
@@ -829,7 +836,7 @@ int write_apidocrec_c(ARGUMENTS *args,
           GWEN_BufferedIO_WriteLine(bio, "<p>");
           dn=GWEN_XMLNode_FindFirstTag(n, "descr", 0, 0);
           if (dn) {
-            if (GWEN_XMLNode_WriteToStream(dn, bio,
+            if (write_xml_to_bio(dn, bio,
                                            GWEN_XML_FLAGS_SIMPLE |
                                            GWEN_XML_FLAGS_INDENT))
               return -1;
@@ -902,7 +909,7 @@ int write_apidoc_c(ARGUMENTS *args,
 
   dn=GWEN_XMLNode_FindFirstTag(node, "descr", 0, 0);
   if (dn) {
-    if (GWEN_XMLNode_WriteToStream(dn, bio,
+    if (write_xml_to_bio(dn, bio,
                                    GWEN_XML_FLAGS_SIMPLE |
                                    GWEN_XML_FLAGS_INDENT))
       return -1;
@@ -1145,7 +1152,7 @@ int main(int argc, char **argv) {
   GWEN_Logger_Open(0, "typemaker",
                    args->logFile,
                    args->logType,
-                   GWEN_LoggerFacilityUser);
+                   GWEN_LoggerFacility_User);
   GWEN_Logger_SetLevel(0, args->logLevel);
 
   inFile=args->params;
